#line 2 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/lexer.c"

#line 4 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/lexer.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 35
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
typedef uint64_t flex_uint64_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;
#endif /* ! C99 */

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! FLEXINT_H */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

/* C99 requires __STDC__ to be defined as 1. */
#if defined (__STDC__)

#define YY_USE_CONST

#endif	/* defined (__STDC__) */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart(yyin  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#define YY_BUF_SIZE 16384
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

extern yy_size_t yyleng;

extern FILE *yyin, *yyout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    #define YY_LESS_LINENO(n)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	yy_size_t yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = 0; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when yytext is formed. */
static char yy_hold_char;
static yy_size_t yy_n_chars;		/* number of characters read into yy_ch_buf */
yy_size_t yyleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = (char *) 0;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow yywrap()'s to do buffer switches
 * instead of setting up a fresh yyin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void yyrestart (FILE *input_file  );
void yy_switch_to_buffer (YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE yy_create_buffer (FILE *file,int size  );
void yy_delete_buffer (YY_BUFFER_STATE b  );
void yy_flush_buffer (YY_BUFFER_STATE b  );
void yypush_buffer_state (YY_BUFFER_STATE new_buffer  );
void yypop_buffer_state (void );

static void yyensure_buffer_stack (void );
static void yy_load_buffer_state (void );
static void yy_init_buffer (YY_BUFFER_STATE b,FILE *file  );

#define YY_FLUSH_BUFFER yy_flush_buffer(YY_CURRENT_BUFFER )

YY_BUFFER_STATE yy_scan_buffer (char *base,yy_size_t size  );
YY_BUFFER_STATE yy_scan_string (yyconst char *yy_str  );
YY_BUFFER_STATE yy_scan_bytes (yyconst char *bytes,yy_size_t len  );

void *yyalloc (yy_size_t  );
void *yyrealloc (void *,yy_size_t  );
void yyfree (void *  );

#define yy_new_buffer yy_create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer(yyin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer(yyin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

typedef unsigned char YY_CHAR;

FILE *yyin = (FILE *) 0, *yyout = (FILE *) 0;

typedef int yy_state_type;

extern int yylineno;

int yylineno = 1;

extern char *yytext;
#define yytext_ptr yytext

static yy_state_type yy_get_previous_state (void );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  );
static int yy_get_next_buffer (void );
static void yy_fatal_error (yyconst char msg[]  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	yyleng = (yy_size_t) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;

#define YY_NUM_RULES 159
#define YY_END_OF_BUFFER 160
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_accept[1190] =
    {   0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
      160,  158,   99,  102,  158,  158,  158,  158,  158,  104,
      104,  158,  107,  107,  107,  107,  107,  107,  107,  107,
      107,  107,  107,  107,  107,  107,  107,  107,  107,  107,
      107,  107,  158,   99,  158,  157,  156,  157,  157,  115,
      113,  115,  101,  107,  107,  107,  107,  107,  107,  107,
      107,  107,  107,  107,  107,  107,  107,  107,  107,  107,
       99,  158,  100,   99,  158,    0,  109,    0,    0,  111,
        0,    0,  104,    0,  108,  105,  108,  112,  103,  105,
        0,  105,  104,    0,   62,  107,  107,  107,  107,  107,

      107,  107,  107,  107,  107,  107,  107,  107,  107,  107,
      107,  107,  107,  107,  107,  107,  107,  107,  107,  107,
      107,  107,  107,  107,  107,  107,  107,  107,  107,   63,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,  114,  107,  107,  107,  107,  107,  107,  107,
       79,  107,  107,  107,  107,  107,  107,  107,  107,  107,
      107,  107,  107,  107,    0,    0,    0,    0,    0,    0,
        0,  105,   64,  108,  105,  103,  105,    0,  105,  106,
      107,  107,  107,  107,  107,  107,  107,  107,  107,  107,

      107,  107,  107,  107,   39,  107,  107,  107,  107,  107,
      107,  107,  107,  107,  107,  107,  107,  107,  107,  107,
      107,  107,  107,  107,  107,  107,  107,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
       13,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,  107,
      107,  107,  107,  107,  107,   78,  107,  107,  107,  107,
      107,  107,  107,  107,   87,  107,  107,  107,  107,    0,
        0,    0,  105,   52,  107,  107,  107,  107,  107,   37,
       35,  107,  107,  107,   45,  107,  107,  107,  107,   40,

      107,  107,  107,  107,  107,  107,  107,  107,  107,  107,
      107,  107,  107,  107,   50,  107,  107,  107,  107,   43,
      107,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        8,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,  155,  107,   97,  107,  107,  107,  107,  107,  107,
      107,   83,  107,  107,  107,  107,  107,  107,   90,  107,
        9,  110,  107,  107,  107,  107,  107,  107,   23,   48,
      107,  107,   51,   60,   41,  107,  107,  107,  107,  107,

      107,   38,  107,  107,  107,   32,  107,  107,  107,   56,
      107,   25,  107,  107,  107,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,   98,  107,  107,  107,  107,
      107,  107,  107,  107,   85,  107,  107,  107,  107,  107,
      107,  107,  107,  107,   34,  107,  107,   42,  107,  107,
      107,  107,  107,  107,   26,  107,   46,   61,   49,   24,
      107,  107,  107,  107,  107,    0,    0,    0,    0,    0,

        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,  107,  107,  107,
       77,  107,  107,  107,  107,  107,  107,  107,  107,  107,
      107,  107,  107,  107,   33,  107,  107,  107,  107,  107,
      107,  107,  107,  107,  107,  107,  107,  107,   28,  107,
       29,  107,   53,  107,   44,   36,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,   14,    0,

        0,    0,    0,    0,    0,   18,    0,    0,   20,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,  107,  107,  107,  107,  107,  107,  107,
      107,  107,  107,  107,  107,  107,  107,  107,   31,  107,
      107,  107,  107,  107,  107,  107,  107,  107,  107,   58,
      107,   57,   55,  107,   59,   47,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,  120,    0,    0,    0,
        0,  126,   11,    0,    0,    0,  152,    0,   15,    0,
        0,   16,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,  153,    0,    0,    0,    0,    0,

        0,    0,  107,  107,  107,  107,   81,   82,   84,  107,
      107,  107,  107,  107,  107,   74,  107,   30,  107,  107,
      107,  107,  107,  107,  107,  107,  107,  107,   54,   27,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,   21,    0,    0,   22,  136,    0,    0,
      133,    0,    0,    0,  107,  107,  107,  107,  107,  107,
       88,   89,  107,  107,   75,  107,  107,   68,   73,   67,
      107,  107,  107,   71,  107,    0,    0,    0,    0,    0,

        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
      150,   10,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,   19,    0,    0,    0,  147,
        0,    0,    0,    0,    0,    0,  107,  107,  107,  107,
      107,  107,  107,  107,  107,  107,  107,   70,   66,   76,
      151,    1,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,   17,  137,  135,    0,  146,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,  107,
      107,  107,  107,  107,  107,  107,  107,   72,  107,   65,

        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,  142,    0,    0,
        0,    0,    0,    0,    0,    0,  123,    0,    0,    0,
        0,    0,    0,  107,  107,  107,  107,  107,  107,  107,
      107,  107,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,  145,    0,    0,    0,    0,    0,  149,    0,
        0,    0,    0,  107,  107,  107,  107,  107,  107,  107,
      107,   69,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,

       12,    0,    0,    0,    0,  138,    0,    0,    0,    0,
        0,  107,  107,  107,  107,  107,   86,  107,  107,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,  141,    0,    0,    0,
        0,  128,    0,    0,    0,    0,  107,   95,  107,  107,
      107,  107,   93,  143,    0,    0,    0,    0,    0,    2,
        0,    0,    0,    0,    5,    6,    0,    0,    0,    0,
        0,    0,    0,    0,    0,  139,    0,    0,  107,  107,
      107,   92,  107,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    7,    0,    0,  132,    0,  127,    0,    0,

        0,    0,    0,  107,  107,   80,  107,    0,    0,  118,
        0,    0,    0,    0,  122,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,  107,  107,   91,    0,    0,
        0,    0,    0,    0,    0,    0,  125,    0,  130,    0,
        0,    0,  140,    0,  107,  107,  119,  116,    0,  144,
      121,    0,    0,    0,    0,    0,    0,  134,  154,  107,
      107,  117,    0,    0,    0,  148,    0,    0,  107,  107,
      124,    0,    0,    0,  129,   94,  107,    3,    0,  131,
      107,    0,  107,    0,  107,    4,  107,   96,    0
    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    4,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    1,    5,    1,    1,    6,    1,    7,    8,
        9,   10,   11,    1,   12,   13,   14,   15,   16,   16,
       16,   16,   16,   16,   16,   16,   16,   17,    1,    1,
        1,    1,    1,    1,   18,   19,   20,   21,   22,   23,
       24,   25,   26,   27,   28,   29,   30,   31,   32,   33,
       34,   35,   36,   37,   38,   39,   40,   28,   41,   42,
        1,   43,    1,    1,   44,    1,   45,   46,   47,   48,

       49,   50,   51,   52,   53,   28,   54,   55,   56,   57,
       58,   59,   28,   60,   61,   62,   63,   64,   65,   66,
       67,   68,    1,   69,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst flex_int32_t yy_meta[70] =
    {   0,
        1,    1,    2,    1,    1,    1,    1,    1,    1,    1,
        1,    3,    3,    3,    4,    4,    1,    4,    4,    4,
        4,    4,    4,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    1,    3,    4,    4,    4,    4,    4,    4,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    1
    } ;

static yyconst flex_int16_t yy_base[1198] =
    {   0,
        0,   68, 2806,   69,   70,   73,   75,   75, 2800,   80,
     2807, 2810, 2810, 2810,   73,   84,   77,   87,   75,  126,
     2740, 2788,   82,   93,   96,  101,  139,  144,  148,  154,
      157,  160,  165,  170,  173,  181,  184,  196,  207,  212,
      220,  223, 2735,  115,  261, 2810, 2810,  138, 2781, 2810,
     2810, 2788, 2810,  248,  229,  240,  263,  252,  290,  293,
      299,  310,  313,  316,  319,  324,  327,  337,  351,  340,
      141, 2779, 2810,  144, 2778,  186, 2810, 2796,  204, 2810,
      243,  103, 2732,  176,  355,  393,  187, 2810,    0,  397,
      410, 2810, 2810,    0, 2810,  368,  381,  415,  418,  422,

      425,  436,  439,  444,  448,  451,  454,  457,  460,  463,
      466,  473,  476,  480,  484,  490,  493,  496,  506,  510,
      513,  522,  528,  532,  537,  547,  550,  553,  557, 2810,
      266,    0,  192, 2771, 2738,  297,  357,  239,  196, 2742,
      481, 2741,  527,  317,  271, 2744,   44, 2735, 2738,  396,
     2768, 2732, 2810,  567,  570,  577,  580,  589,  585,  599,
      602,  605,  611,  615,  624,  628,  634,  637,  640,  643,
      646,  651,  657,  661,  438, 2766, 2721,  439, 2764,  367,
      714,  663,  305,  677,  348,    0,  703,  484,  688,    0,
      686,  727,  742,  730,  710,  733,  736,  763,  768,  771,

      777,  782,  786,  789,  792,  795,  798,  803,  806,  809,
      816,  824,  827,  836,  839,  842,  845,  848,  851,  858,
      863,  868,  871,  877,  882,  885,  889, 2738, 2722,  203,
      496, 2733, 2735, 2733,  326, 2735, 2722,  567, 2716, 2729,
     2810, 2717,  210, 2728, 2715, 2711, 2724, 2724,  581, 2709,
      433, 2716, 2713, 2705, 2710, 2706, 2711, 2703, 2714,  901,
      906,  909,  912,  923,  926,  929,  933,  936,  944,  947,
      951,  957,  960,  964,  967,  971,  976,  987,  995, 2713,
     2753,  998, 1003, 1017, 1020, 1028, 1031, 1034, 1037, 1044,
     1047, 1050, 1055, 1063, 1066, 1069, 1072, 1078, 1081, 1084,

     1087, 1090, 1093, 1096, 1100, 1111, 1114, 1117, 1133, 1122,
     1138, 1141, 1144, 1147, 1155, 1158, 1161, 1166, 1172, 1180,
     1183, 2710, 2700, 2708, 2707, 2696, 2690, 2686, 2707, 2690,
     2810, 2701, 2691, 2688, 2685, 2701, 2690, 2684, 2723, 2693,
     2683, 2685, 2677, 2676, 2688, 2677, 2683, 2671, 2679, 2670,
     2680, 2668,  604, 2670, 2667, 2678, 2706, 2676, 2675, 2661,
     2660, 2810, 1188, 1191, 1195, 1201, 1207, 1211, 1214, 1217,
     1220, 1226, 1234, 1237, 1240, 1245, 1249, 1252, 1255, 1261,
     2810, 2810, 1269, 1272, 1276, 1298, 1305, 1308, 1314, 1319,
     1324, 1327, 1335, 1338, 1341, 1344, 1347, 1350, 1353, 1357,

     1363, 1366, 1369, 1372, 1375, 1378, 1381, 1385, 1388, 1393,
     1404, 1409, 1413, 1417, 1422, 2660, 2687, 2657, 2663, 2659,
     2667, 2662, 2651, 2651, 2653, 2651, 2665, 2646, 2653, 2658,
     2661, 2647, 2673, 2643, 2639, 2648, 2655, 2642, 2649, 2639,
     2641, 2640, 2644, 2640, 2666, 2634, 2641, 2640, 2639, 2642,
     2628, 2630,  134,  184, 2621, 1426, 1429, 1432, 1436, 1442,
     1445, 1451, 1455, 1463, 1459, 1466, 1469, 1472, 1475, 1485,
     1488, 1494, 1497, 1510, 1500, 1554, 1517, 1526, 1535, 1539,
     1542, 1545, 1548, 1557, 1565, 1568, 1580, 1586, 1592, 1595,
     1598, 1601, 1604, 1608, 1611, 2622, 2615, 1607, 2632, 2619,

     2619, 2621, 2622, 2616, 2613, 2612, 2626, 2612, 2618, 2625,
     2605, 2620, 2622, 2604, 2617, 2619, 2606, 2601, 2613, 2612,
     2610, 2609, 2599, 2599, 2598, 2601, 2591, 2592, 2631, 2589,
     2601, 2595, 2589,  634, 2588, 2587, 2599, 1618, 1621, 1624,
     1627, 1632, 1636, 1642, 1645, 1652, 1655, 1662, 1665, 1680,
     1683, 1669, 1688, 1692, 1695, 1702, 1705, 1715, 1720, 1730,
     1733, 1736, 1741, 1745, 1748, 1754, 1757, 1760, 1763, 1772,
     1776, 1779, 1782, 1785, 1790, 1793, 2623, 2611, 2578, 2588,
     2590, 2589, 2577, 2591, 2582, 2572, 2582, 2570, 2578, 2577,
     2580, 2566, 2578, 2565, 2565, 2575, 2574, 2566, 2810, 2572,

     2565, 2572, 2567, 2556, 2572,  681, 2571, 2530, 2810, 2536,
     2526, 2535, 2524, 2527, 2535, 2533, 2524, 2531, 2533, 2519,
     2527, 2513, 2518, 1799, 1802, 1810, 1813, 1817, 1822, 1825,
     1828, 1831, 1834, 1837, 1850, 1855, 1860, 1870, 1875, 1878,
     1883, 1886, 1890, 1903, 1906, 1911, 1917, 1922, 1929, 1932,
     1935, 1940, 1944, 1947, 1950, 1953, 2514, 2525, 2519, 2523,
     2522, 2515, 2512, 2503, 2501,  584, 2810,  736, 2504, 2502,
     2511, 2810, 2810, 2513, 2537, 2493, 2810, 2503, 2810, 2472,
     2472, 2810, 2437, 2444, 2443, 2441, 2431, 2430, 2422, 2395,
     2389, 2376, 2387, 2414, 2810, 2383, 2382, 2381, 2362, 2374,

     2350,  555, 1956, 1959, 1962, 1965, 1968, 1973, 1976, 1979,
     1984, 1990, 1999, 2003, 2006, 2012, 2015, 2018, 2022, 2028,
     2034, 2037, 2041, 2048, 2052, 2061, 2067, 2070, 2073, 2079,
     2359, 2350, 2348, 2334, 2345, 2371, 2324, 2336, 2330, 2293,
     2287, 2280, 2276, 2283, 2262, 2269, 2262,  606, 2255, 2258,
     2250, 2249, 2237, 2275, 2208, 2198, 2196, 2198, 2193, 2179,
     2185, 2189, 2185, 2810, 2182, 2151, 2810, 2810, 2134, 2162,
     2810, 2151, 2127, 2111, 2082, 2085, 2088, 2091, 2094, 2097,
     2103, 2106, 2109, 2115, 2118, 2121, 2126, 2134, 2140, 2147,
     2153, 2156, 2162, 2167, 2173, 2114, 2113, 2108, 2136, 2131,

     2091, 2088, 2117, 2095, 2066,  479, 2066, 2065, 2026, 2017,
     2810, 2810, 2020, 1996, 2003, 2004, 1995, 1984, 1993, 1979,
     1973, 1972, 1965, 1961, 1958, 2810, 1961, 1945, 1979, 2810,
     1946, 1923, 1882, 1881,  640, 1872, 2176, 2179, 2182, 2185,
     2188, 2191, 2194, 2199, 2202, 2205, 2208, 2213, 2216, 2236,
     2810, 2810, 1867, 1863, 1858, 1847, 1890, 1844, 1847, 1829,
     1818, 1812, 1817, 1818, 1830, 1821, 1820, 1800, 1800, 1807,
     1835, 1808, 1790, 1784, 2810, 2810, 2810, 1769, 2810, 1762,
     1756, 1750, 1751, 1763, 1733, 1733, 1723, 1717, 1705, 2240,
     2243, 2246, 2249, 2252, 2256, 2259, 2262, 2265, 2268, 2271,

     1718, 1686, 1685, 1673, 1663, 1674, 1674, 1675, 1665, 1644,
     1636, 1641, 1626, 1625, 1624, 1621, 1605, 2810, 1603, 1605,
     1575, 1553, 1536, 1542, 1528, 1539, 2810, 1527, 1523, 1509,
     1543, 1498, 1484, 2274, 2277, 2280, 2288, 2291, 2301, 2310,
     2314, 2317, 1484, 1485, 1483, 1470, 1476, 1475, 1458, 1450,
     1495, 1454, 1435, 1441, 1425, 1428, 1412, 1435, 1432, 1403,
     1383, 1361, 2810, 1394, 1352, 1366, 1360, 1360, 2810, 1309,
     1310, 1296, 1318, 2323, 2328, 2335, 2338, 2343, 2348, 2351,
     2354, 2357, 1294, 1285, 1280, 1304, 1273, 1266, 1259, 1249,
     1250, 1284, 1249, 1243, 1240, 1229, 1235, 1240, 1233, 1230,

     2810, 1221, 1218, 1226, 1198, 2810, 1195, 1194, 1193, 1176,
     1177, 2361, 2364, 2370, 2376, 2383, 2388, 2391, 2397, 1167,
     1151, 1150, 1140, 1141, 1129, 1138, 1133, 1136, 1107, 1106,
     1093, 1093, 1081, 1119, 1075, 1072, 2810, 1099, 1068, 1053,
     1035, 2810, 1038, 1025, 1052, 1014, 2402, 2405, 2408, 2425,
     2428, 2432, 2439, 2810, 1034, 1032,  990,  977, 1015, 2810,
     1007,  963,  975,  969, 2810, 2810,  967,  953,  943,  954,
      944,  948,  942,  936,  972, 2810,  933,  938, 2442, 2445,
     2448, 2451, 2454,  917,  908,  905,  932,  893,  874,  870,
      879,  321, 2810,  879,  889, 2810,  860, 2810,  848,  848,

      842,   31,   49, 2457, 2460, 2463, 2466,   76,  132, 2810,
      172,  266,  286,  363, 2810,  338,  353,  368,  437,  498,
      499,  566,  557,  571,  617, 2469, 2480, 2483,  618,  627,
      636,  645,  659,  651,  660,  676, 2810,  680, 2810,  711,
      693,  718, 2810,  709, 2486, 2494, 2810, 2810,  721, 2810,
     2810,  725,  722,  729,  738,  734,  765, 2810, 2810, 2498,
     2501, 2810,  776,  781,  788, 2810,  787,  793, 2505, 2510,
     2810,  782,  783,  818, 2810, 2516, 2520, 2810,  805, 2810,
     2523,  814, 2528,  837, 2531, 2810, 2534, 2537, 2810, 2594,
     2598, 2602, 2606, 2608, 2610, 2614,  888

    } ;

static yyconst flex_int16_t yy_def[1198] =
    {   0,
     1189,    1, 1190, 1190, 1191, 1191,    1,    7,    1,    1,
     1189, 1189, 1189, 1189, 1192, 1193, 1189, 1194, 1189, 1189,
       20, 1189, 1195, 1195, 1195, 1195, 1195, 1195, 1195, 1195,
     1195, 1195, 1195, 1195, 1195, 1195, 1195, 1195, 1195, 1195,
     1195, 1195, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189,
     1189, 1189, 1189, 1195, 1195, 1195, 1195, 1195, 1195, 1195,
     1195, 1195, 1195, 1195, 1195, 1195, 1195, 1195, 1195, 1195,
     1189,   45, 1189, 1189,   45, 1192, 1189, 1192, 1193, 1189,
     1193, 1189,   20, 1194, 1194, 1194, 1194, 1189, 1196, 1189,
     1189, 1189, 1189, 1197, 1189, 1195, 1195, 1195, 1195, 1195,

     1195, 1195, 1195, 1195, 1195, 1195, 1195, 1195, 1195, 1195,
     1195, 1195, 1195, 1195, 1195, 1195, 1195, 1195, 1195, 1195,
     1195, 1195, 1195, 1195, 1195, 1195, 1195, 1195, 1195, 1189,
     1189,   45, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189,
     1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189,
     1189, 1189, 1189, 1195, 1195, 1195, 1195, 1195, 1195, 1195,
     1195, 1195, 1195, 1195, 1195, 1195, 1195, 1195, 1195, 1195,
     1195, 1195, 1195, 1195, 1189,   45, 1189, 1189,   45, 1189,
     1193, 1189, 1194, 1194, 1194, 1196, 1189, 1189, 1189, 1197,
     1195, 1195, 1195, 1195, 1195, 1195, 1195, 1195, 1195, 1195,

     1195, 1195, 1195, 1195, 1195, 1195, 1195, 1195, 1195, 1195,
     1195, 1195, 1195, 1195, 1195, 1195, 1195, 1195, 1195, 1195,
     1195, 1195, 1195, 1195, 1195, 1195, 1195, 1189, 1189, 1189,
     1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189,
     1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189,
     1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1195,
     1195, 1195, 1195, 1195, 1195, 1195, 1195, 1195, 1195, 1195,
     1195, 1195, 1195, 1195, 1195, 1195, 1195, 1195, 1195, 1189,
      181, 1194, 1194, 1195, 1195, 1195, 1195, 1195, 1195, 1195,
     1195, 1195, 1195, 1195, 1195, 1195, 1195, 1195, 1195, 1195,

     1195, 1195, 1195, 1195, 1195, 1195, 1195, 1195, 1195, 1195,
     1195, 1195, 1195, 1195, 1195, 1195, 1195, 1195, 1195, 1195,
     1195, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189,
     1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189,
     1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189,
     1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189,
     1189, 1189, 1195, 1195, 1195, 1195, 1195, 1195, 1195, 1195,
     1195, 1195, 1195, 1195, 1195, 1195, 1195, 1195, 1195, 1195,
     1189, 1189, 1195, 1195, 1195, 1195, 1195, 1195, 1195, 1195,
     1195, 1195, 1195, 1195, 1195, 1195, 1195, 1195, 1195, 1195,

     1195, 1195, 1195, 1195, 1195, 1195, 1195, 1195, 1195, 1195,
     1195, 1195, 1195, 1195, 1195, 1189, 1189, 1189, 1189, 1189,
     1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189,
     1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189,
     1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189,
     1189, 1189, 1189, 1189, 1189, 1195, 1195, 1195, 1195, 1195,
     1195, 1195, 1195, 1195, 1195, 1195, 1195, 1195, 1195, 1195,
     1195, 1195, 1195, 1195, 1195, 1195, 1195, 1195, 1195, 1195,
     1195, 1195, 1195, 1195, 1195, 1195, 1195, 1195, 1195, 1195,
     1195, 1195, 1195, 1195, 1195, 1189, 1189, 1189, 1189, 1189,

     1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189,
     1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189,
     1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189,
     1189, 1189, 1189, 1189, 1189, 1189, 1189, 1195, 1195, 1195,
     1195, 1195, 1195, 1195, 1195, 1195, 1195, 1195, 1195, 1195,
     1195, 1195, 1195, 1195, 1195, 1195, 1195, 1195, 1195, 1195,
     1195, 1195, 1195, 1195, 1195, 1195, 1195, 1195, 1195, 1195,
     1195, 1195, 1195, 1195, 1195, 1195, 1189, 1189, 1189, 1189,
     1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189,
     1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189,

     1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189,
     1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189,
     1189, 1189, 1189, 1195, 1195, 1195, 1195, 1195, 1195, 1195,
     1195, 1195, 1195, 1195, 1195, 1195, 1195, 1195, 1195, 1195,
     1195, 1195, 1195, 1195, 1195, 1195, 1195, 1195, 1195, 1195,
     1195, 1195, 1195, 1195, 1195, 1195, 1189, 1189, 1189, 1189,
     1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189,
     1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189,
     1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189,
     1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189,

     1189, 1189, 1195, 1195, 1195, 1195, 1195, 1195, 1195, 1195,
     1195, 1195, 1195, 1195, 1195, 1195, 1195, 1195, 1195, 1195,
     1195, 1195, 1195, 1195, 1195, 1195, 1195, 1195, 1195, 1195,
     1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189,
     1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189,
     1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189,
     1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189,
     1189, 1189, 1189, 1189, 1195, 1195, 1195, 1195, 1195, 1195,
     1195, 1195, 1195, 1195, 1195, 1195, 1195, 1195, 1195, 1195,
     1195, 1195, 1195, 1195, 1195, 1189, 1189, 1189, 1189, 1189,

     1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189,
     1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189,
     1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189,
     1189, 1189, 1189, 1189, 1189, 1189, 1195, 1195, 1195, 1195,
     1195, 1195, 1195, 1195, 1195, 1195, 1195, 1195, 1195, 1195,
     1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189,
     1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189,
     1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189,
     1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1195,
     1195, 1195, 1195, 1195, 1195, 1195, 1195, 1195, 1195, 1195,

     1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189,
     1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189,
     1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189,
     1189, 1189, 1189, 1195, 1195, 1195, 1195, 1195, 1195, 1195,
     1195, 1195, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189,
     1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189,
     1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189,
     1189, 1189, 1189, 1195, 1195, 1195, 1195, 1195, 1195, 1195,
     1195, 1195, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189,
     1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189,

     1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189,
     1189, 1195, 1195, 1195, 1195, 1195, 1195, 1195, 1195, 1189,
     1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189,
     1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189,
     1189, 1189, 1189, 1189, 1189, 1189, 1195, 1195, 1195, 1195,
     1195, 1195, 1195, 1189, 1189, 1189, 1189, 1189, 1189, 1189,
     1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189,
     1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1195, 1195,
     1195, 1195, 1195, 1189, 1189, 1189, 1189, 1189, 1189, 1189,
     1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189,

     1189, 1189, 1189, 1195, 1195, 1195, 1195, 1189, 1189, 1189,
     1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189,
     1189, 1189, 1189, 1189, 1189, 1195, 1195, 1195, 1189, 1189,
     1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189,
     1189, 1189, 1189, 1189, 1195, 1195, 1189, 1189, 1189, 1189,
     1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1195,
     1195, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1195, 1195,
     1189, 1189, 1189, 1189, 1189, 1195, 1195, 1189, 1189, 1189,
     1195, 1189, 1195, 1189, 1195, 1189, 1195, 1195,    0, 1189,
     1189, 1189, 1189, 1189, 1189, 1189, 1189

    } ;

static yyconst flex_int16_t yy_nxt[2880] =
    {   0,
       12,   13,   14,   13,   15,   12,   16,   12,   12,   12,
       12,   17,   18,   19,   20,   21,   22,   23,   23,   23,
       23,   23,   23,   23,   23,   23,   23,   23,   23,   23,
       24,   23,   25,   26,   23,   27,   23,   23,   23,   23,
       23,   23,   12,   23,   23,   28,   29,   30,   31,   32,
       23,   23,   33,   23,   34,   23,   35,   36,   37,   23,
       38,   39,   40,   41,   42,   23,   23,   23,   43,   44,
       48,   47,   51,   45,   49,   51,   71,   77, 1124,   52,
       72,   74,   52,   53,   88,   75,   80,   73,   89,   82,
       80,   83,   83,   84,   87,   84,  255,   54,   84,   85,

       84,   86,   86, 1125,   84,   87,   84,   84,   87,   84,
      256,   55,   84,   87,   84,   78,  131,  182,  182,   56,
      132,   57,   58, 1129,   59,   60,   81,   61,   62,   63,
       97,   64,   65,   66,   67,   68,   69,   70,   90,  150,
       83,   83,  175,  151,   99,  178,  176,   91,   92,  179,
       84,   87,   84,  533,   93,   84,   87,   84,  534,   84,
       87,   84,   98,   93,  100,   84,   87,   84,   84,   87,
       84,   84,   87,   84,   91,   92,   84,   87,   84, 1130,
       93,   84,   87,   84,   84,   87,   84,   84,   93,   84,
       77,   94,   84,   87,   84,   84,   87,   84,   84,  102,

       84,  101,  103,  535,  108,  104,   80,   84,   87,   84,
       80,  105,  109,  106,  110,  238,  536,  113,   84,   87,
       84,  111,  107,   84,   87,   84,  324,  112,   78, 1131,
      114,   84,   87,   84,   84,   87,   84,  325,  228,  115,
       84,   87,   84,  116,  239,   80,  117,  118,  119,   80,
      120,   84,   87,   84,  229,  122,  342,  121,  123,   84,
       87,   84,  343,   84,   87,   84,  124,  131,  126,  129,
      344,  132,  127,  125,   84,   87,   84,  128,  133,  134,
      135,  136,  137,  138,  139,  140,  141,  236,  155,  142,
      143,  237,  154,  144,  156,  145,  146,  147,  148,  149,

      158,   84,   87,   84,   84,   87,   84,  157,  181,  105,
       84,   87,   84, 1132,  102,  252,   84,  103,   84,  253,
      104,   84,   87,   84,   84,   87,   84,   84,   87,   84,
       84,   87,   84, 1133,  108,   84,   87,   84,   84,   87,
       84,  160,  109, 1116,  110,  232,  161,  159,   84,   87,
       84,   84,   87,   84,  233,  111, 1117,  163,  162,   84,
      165,   84,   84,   87,   84,  164,   84,  183,   84,  248,
      112,  249,  332,  114,  250,  169,  251,  166,  167,   84,
       87,   84, 1134,  116,  333,  170,  117,  334,  118,  171,
      168,  120,   84,   87,   84, 1135,  126,  150,  121,  122,

      174,  151,  123,  172,   84, 1136,   84,   86,   86,  191,
      124,  187,  187,  234,  184,  185, 1137,  173,   91,   92,
      188,  188,  235,  280,  189,  189,   84,   87,   84,   84,
       87,   84,  235,   84,   87,   84,   84,   87,   84,  175,
      178,  184,  185,  176,  179,   91,   92,   84,   87,   84,
       84,   87,   84,  193,  194,   84,   87,   84,  192,   84,
       87,   84,   84,   87,   84,   84,   87,   84,   84,   87,
       84,   84,   87,   84,   84,   87,   84,   84,   87,   84,
      196,  353,  195,  197,   84,   87,   84,   84,   87,   84,
      354,   84,   87,   84, 1138,   84,   87,   84,  189,  189,

      198,   84,   87,   84,   84,   87,   84,   84,   87,   84,
      199,  202,  201,  200,  861,  862,  203,   84,   87,   84,
      204,   84,   87,   84,   84,   87,   84,  205,  208,  206,
      241,  207,  209,   84,   87,   84,  242,  243,  212,   84,
       87,   84,  210,   84,   87,   84, 1139,  211,   84,   87,
       84,  326,  327,  213,  328, 1140,  214,  217,   84,   87,
       84,   84,   87,   84,   84,   87,   84,  216,   84,   87,
       84,  245,  218,  215,  773,  246,  774,  219,   84,   87,
       84,   84,   87,   84,  247, 1141,  337,  220,   84,   87,
       84,   84,   87,   84,  221,  222,   84,   87,   84,  223,

       84,   87,   84,  338, 1142,  226,  740,  224,  227,  225,
       84,   87,   84,   84,   87,   84,   84,   87,   84, 1143,
      741,  260,   84,   87,   84,  350,   84,   87,   84,  446,
      813,  262,  261,  447,  263,   84,   87,   84,  264,   84,
       87,   84,  814,  351,  265,   84,   87,   84,   84,   87,
       84,   84,   87,   84,   84,   87,   84,   84,   87,   84,
      266,  269,   84,   87,   84, 1144, 1147,  268,   84,   87,
       84,  267,   84,   87,   84, 1148,  209,  182,  182,  270,
      273,  272,  619, 1149,   91,   92,  620,  188,  282,  271,
       84,  283,  283, 1150,  887,  274,  276,   84,   87,   84,

      685,  888,  189,  189,  275,  686,  277, 1151, 1152,  279,
       92,   91,   92,  215,  284,  278,   80,  187,  187, 1153,
       80,   84,   87,   84,   91,   92, 1154, 1155,  281,  281,
     1156,  281,  281,  281,  281,  281,  281,   92,   84,   87,
       84,   84,   87,   84,   84,   87,   84,   84,   87,   84,
     1157,   91,   92,   84,   87,   84,  742,  743,  281,  281,
      281,  281,  281,  281,  290,  744, 1158,  287, 1159, 1162,
      288,  745, 1163,  289,   84,   87,   84, 1164,  285,   84,
       87,   84,   84,   87,   84, 1165, 1166,  286,   84,   87,
       84, 1167,  291,   84,   87,   84,  292,   84,   87,   84,

       84,   87,   84,   84,   87,   84,   84,   87,   84,   84,
       87,   84, 1168,  294,   84,   87,   84,   84,   87,   84,
       84,   87,   84,  293, 1171, 1172,  295,   84,   87,   84,
      298,  296, 1173,  299, 1174,   84,   87,   84,   84,   87,
       84, 1175,  297, 1178, 1179,  300,  301,   84,   87,   84,
       84,   87,   84,   84,   87,   84,   84,   87,   84,   84,
       87,   84,   84,   87,   84,  303, 1180, 1182,  302,   84,
       87,   84,  304, 1184,   84,   87,   84,  305,  306,   84,
       87,   84,   84,   87,   84, 1186,  307,  309,   84,   87,
       84,  190,  308,   84,   87,   84,   84,   87,   84, 1123,

       84,   87,   84,  310, 1122, 1121,  311, 1120, 1119,  313,
      312,  315,   84,   87,   84,  314,  316,   84,   87,   84,
       84,   87,   84,   84,   87,   84, 1118, 1115,  317,  318,
     1114, 1113,  320,  321,   84,   87,   84,   84,   87,   84,
       84,   87,   84,  319,   84,   87,   84,   84,   87,   84,
     1112, 1111,  365, 1110,  364,   84,   87,   84,   84,   87,
       84,  363,   84,   87,   84, 1109,  366,  367,   84,   87,
       84,   84,   87,   84, 1108,   84,   87,   84,   84,   87,
       84,  368,   84,   87,   84, 1103,  370,   84,   87,   84,
     1102, 1101,  371, 1100, 1099,  372, 1098,  369,   84,   87,

       84, 1097, 1096,  373, 1095,  374,   84,   87,   84,   84,
     1094,   84,  283,  283,   84, 1093,   84,  283,  283, 1092,
      375,  376, 1091, 1090,  378,  185, 1089,  377,   84,   87,
       84,   84,   87,   84, 1088,  379, 1087, 1086,  380,   84,
       87,   84,   84,   87,   84,   84,   87,   84,   84,   87,
       84, 1085,  185, 1084,  385,   84,   87,   84,   84,   87,
       84,   84,   87,   84,  383,  386,   84,   87,   84,  387,
     1078, 1077,  388, 1076,   84,   87,   84,   84,   87,   84,
       84,   87,   84,   84,   87,   84, 1075, 1074,  384,   84,
       87,   84,   84,   87,   84,   84,   87,   84,   84,   87,

       84,   84,   87,   84,   84,   87,   84,   84,   87,   84,
      389,   84,   87,   84, 1073, 1072,  390,  391, 1071, 1070,
      393,  392,   84,   87,   84,   84,   87,   84,   84,   87,
       84, 1069,  394,   84,   87,   84,  397,  398, 1068, 1067,
      399, 1066,  395, 1065,   84,   87,   84,  396,  400,   84,
       87,   84,   84,   87,   84,   84,   87,   84,   84,   87,
       84,  403, 1064,  401, 1063,  404,   84,   87,   84,   84,
       87,   84,   84,   87,   84,  402,  405,   84,   87,   84,
     1062, 1061,  406,   84,   87,   84, 1060,  408, 1059, 1058,
      407,   84,   87,   84,   84,   87,   84, 1057,  409,   84,

       87,   84,   84,   87,   84,  411,   84,   87,   84, 1056,
     1055,  410,   84,   87,   84, 1054,  413,  412,   84,   87,
       84, 1046,   84,   87,   84,   84,   87,   84,   84,   87,
       84,   84,   87,   84,  414, 1045,  456,   84,   87,   84,
     1044, 1043,  415, 1042,  458,   84,   87,   84,   84,   87,
       84,   84,   87,   84,  457,  460,   84,   87,   84, 1041,
       84,   87,   84,   84,   87,   84,   84,   87,   84,  459,
     1040,  461,   84,   87,   84, 1039,  463, 1038, 1037,  462,
       84,   87,   84,   84,   87,   84,  396,   84,   87,   84,
     1036,  464, 1035,  468, 1034, 1033,  465,  404, 1032, 1031,

      466, 1030,  411, 1029, 1028,  470,  474, 1027,  467,   84,
       87,   84,  469, 1026, 1025,  471,   84,   87,   84,   84,
       87,   84, 1024, 1023,  473,   84,   87,   84, 1022,  472,
       84,   87,   84, 1021,  475,   84,   87,   84,   84,   87,
       84, 1020, 1011,  477, 1010,  476,   84,   87,   84,   84,
       87,   84,   84,   87,   84,   84,   87,   84,   84,   87,
       84,   84,   87,   84,   84,   87,   84, 1009,   84,   87,
       84, 1008,  478,  479,   84,   87,   84,   84,   87,   84,
       84,   87,   84,   84,   87,   84,   84,   87,   84,   84,
       87,   84,   84,   87,   84,  481,   84,   87,   84,   84,

       87,   84,  480,  484,   84,   87,   84, 1007, 1006,  485,
     1005,  482, 1004, 1003,  483,   84,   87,   84, 1002,  487,
       84,   87,   84,  486,   84,   87,   84,  489,   84,   87,
       84, 1001,  491,   84,   87,   84,  488,   84,   87,   84,
       84,   87,   84,   84,   87,   84,  490,   84,   87,   84,
     1000,  999,  492,   84,   87,   84,   84,   87,   84,  998,
      997,  494,   84,   87,   84,  495,   84,   87,   84,  493,
       84,   87,   84,  538,   84,   87,   84,   84,   87,   84,
       84,   87,   84,   84,   87,   84,   84,   87,   84,  996,
      540,  995,  539,  994,  993,  543,   84,   87,   84,   84,

       87,   84,  992,  541,  542,   84,   87,   84,   84,   87,
       84,   84,   87,   84,  991,  544,  990,  547,  546,  545,
      989,   84,   87,   84,  988,  987,  486,  554,   84,   87,
       84,  986,  985,  548,  984,  555,  549,   84,   87,   84,
      551,  983,  564,  973,  550,  552,   84,   87,   84,  972,
       84,   87,   84,   84,   87,   84,   84,   87,   84,   84,
       87,   84,  971,  970,  553,   84,   87,   84,   84,   87,
       84,  969,  556,  557,  558,  559,   84,   87,   84,   84,
       87,   84,  560,  566,  968,  561,  967,  565,  966,  562,
      563,   84,   87,   84,  965,  964,  569,   84,   87,   84,

      567,  963,  568,   84,   87,   84,   84,   87,   84,   84,
       87,   84,   84,   87,   84,   84,   87,   84,  570,   84,
       87,   84,   84,   87,   84,  579,  580,  962,  571,   84,
       87,   84,   84,   87,   84,   84,   87,   84,   84,   87,
       84,  581,  582,   84,   87,   84,  583,   84,   87,   84,
      573,  961,  574,   84,   87,   84,   84,   87,   84,  572,
      960,  959,  575,   84,   87,   84,   84,   87,   84,  958,
      624,  957,  576,   84,   87,   84,   84,   87,   84,  627,
       84,   87,   84,  625,  956,  626,  628,  955,  954,  630,
      629,   84,   87,   84,   84,   87,   84,  953,  632,   84,

       87,   84,  952,   84,   87,   84,   84,   87,   84,  634,
      951,  950,  637,   84,   87,   84,   84,   87,   84,  631,
      639,  949,  641,  948,  633,  947,   84,   87,   84,  946,
      635,   84,   87,   84,  945,  944,  638,  943,  636,  640,
      642,   84,   87,   84,   84,   87,   84,   84,   87,   84,
      643,  645,   84,   87,   84,  644,   84,   87,   84,   84,
       87,   84,  933,  932,  646,   84,   87,   84,   84,   87,
       84,   84,   87,   84,   84,   87,   84,  931,  647,  930,
      929,  648,  928,   84,   87,   84,  649,   84,   87,   84,
       84,   87,   84,   84,   87,   84,   84,   87,   84,  927,

      651,   84,   87,   84,   84,   87,   84,  926,  925,  650,
       84,   87,   84,   84,   87,   84,  924,  923,  652,  653,
      654,   84,   87,   84,   84,   87,   84,  655,   84,   87,
       84,  922,  656,   84,   87,   84,   84,   87,   84,   84,
       87,   84,   84,   87,   84,   84,   87,   84,   84,   87,
       84,  921,  920,  705,  919,  918,  706,  917,  916,  703,
      704,   84,   87,   84,  915,  707,   84,   87,   84,  914,
      708,   84,   87,   84,  913,  912,  710,  911,  910,  709,
      909,   84,   87,   84,  908,  711,   84,   87,   84,   84,
       87,   84,  713,  712,   84,   87,   84,   84,   87,   84,

      719,   84,   87,   84,  907,  721,  906,  715,  905,  904,
      718,  720,  714,  717,   84,   87,   84,   84,   87,   84,
      903,  716,   84,   87,   84,  902,  901,  722,   84,   87,
       84,  889,  724,   84,   87,   84,  725,  886,  723,  885,
       84,   87,   84,   84,   87,   84,   84,   87,   84,  726,
      728,   84,   87,   84,  727,   84,   87,   84,   84,   87,
       84,   84,   87,   84,   84,   87,   84,   84,   87,   84,
       84,   87,   84,   84,   87,   84,   84,   87,   84,   84,
       87,   84,  884,  729,   84,   87,   84,   84,   87,   84,
       84,   87,   84,  883,  730,   84,   87,   84,  882,  881,

      777,   84,   87,   84,  775,  880,  879,  776,  878,  778,
       84,   87,   84,  877,   84,   87,   84,   84,   87,   84,
      876,  875,  779,   84,   87,   84,   84,   87,   84,   84,
       87,   84,  780,   84,   87,   84,  874,  873,  781,   84,
       87,   84,  872,  871,  786,   84,   87,   84,   84,   87,
       84,  870,   84,   87,   84,  869,  787,  782,  783,   84,
       87,   84,  868,   84,   87,   84,  789,  784,  867,  791,
      788,  792,   84,   87,   84,  866,  785,  790,   84,   87,
       84,   84,   87,   84,   84,   87,   84,  865,  794,  793,
       84,   87,   84,   84,   87,   84,   84,   87,   84,   84,

       87,   84,   84,   87,   84,   84,   87,   84,   84,   87,
       84,  864,  863,  795,   84,   87,   84,   84,   87,   84,
       84,   87,   84,  860,  859,  837,   84,   87,   84,   84,
       87,   84,   84,   87,   84,  858,  857,   84,   87,   84,
      839,  842,  845,  846,  838,   84,   87,   84,  856,  855,
      840,   84,   87,   84,  854,  841,  853,  843,   84,   87,
       84,  852,  851,  844,   84,   87,   84,   84,   87,   84,
      836,  835,  847,   84,   87,   84,  834,  848,   84,   87,
       84,  833,  832,  849,   84,   87,   84,   84,   87,   84,
       84,   87,   84,   84,   87,   84,   84,   87,   84,   84,

       87,   84,   84,   87,   84,   84,   87,   84,  831,  850,
       84,   87,   84,   84,   87,   84,   84,   87,   84,   84,
       87,   84,  891,  899,   84,   87,   84,   84,   87,   84,
      830,  894,  829,  828,  890,  893,  898,  827,  895,  826,
      825,  892,  824,  823,  900,  822,  897,   84,   87,   84,
      896,   84,   87,   84,   84,   87,   84,   84,   87,   84,
       84,   87,   84,   84,   87,   84,  821,   84,   87,   84,
       84,   87,   84,   84,   87,   84,   84,   87,   84,   84,
       87,   84,   84,   87,   84,   84,   87,   84,   84,   87,
       84,   84,   87,   84,  820,  935,  942,  819,  938,   84,

       87,   84,   84,   87,   84,  941,  934,  936,  939,  818,
      817,  937,   84,   87,   84,  816,  815,  974,  812,  811,
      940,   84,   87,   84,  810,   84,   87,   84,   84,   87,
       84,  809,  808,  975,   84,   87,   84,  807,  982,   84,
       87,   84,  976,  977,  806,  978,   84,   87,   84,   84,
       87,   84,  805,  980,   84,   87,   84,  979,  981,   84,
       87,   84,   84,   87,   84,   84,   87,   84,   84,   87,
       84, 1012,   84,   87,   84,   84,   87,   84,  804, 1014,
     1013,   84,   87,   84,  803,  802, 1015,   84,   87,   84,
      801, 1016,  800,  799,   84,   87,   84,  798, 1017,   84,

       87,   84,   84,   87,   84,  797,  796, 1018,   84,   87,
       84,  772, 1019,   84,   87,   84,   84,   87,   84,   84,
       87,   84,  771,  770, 1049, 1048, 1047, 1051,  769, 1080,
      768,  767, 1050,  766,  765, 1052,   84,   87,   84,   84,
       87,   84,  764,   84,   87,   84,  763,  762, 1079, 1053,
       84,   87,   84,   84,   87,   84,   84,   87,   84,   84,
       87,   84,   84,   87,   84,   84,   87,   84,   84,   87,
       84,   84,   87,   84,   84,   87,   84,   84,   87,   84,
       84,   87,   84,  761, 1082,  760, 1081, 1083,  759,  758,
     1104,   84,   87,   84,   84,   87,   84,   84,   87,   84,

      757,  756, 1107,  755, 1105,   84,   87,   84, 1106,   84,
       87,   84,   84,   87,   84, 1126,   84,   87,   84, 1127,
      754,   84,   87,   84,  753, 1170, 1128,   84,   87,   84,
     1145,   84,   87,   84,   84,   87,   84, 1146, 1160,   84,
       87,   84,   84,   87,   84,   84,   87,   84,   84,   87,
       84,  752,  751, 1161, 1177, 1169,  750,  749,  748,  747,
      746, 1176,  739,  738,  737,  736,  735,  734,  733,  732,
     1183,  731,  702,  701,  700,  699, 1181,  698,  697, 1187,
      696,  695, 1185,  694,  693,  692,  691,  690,  689,  688,
      687,  684,  683, 1188,   46,   46,   46,   46,   50,   50,

       50,   50,   76,   76,   76,   76,   79,   79,   79,   79,
       87,   87,   96,   96,  186,  682,  186,  186,  681,  680,
      679,  678,  677,  676,  675,  674,  673,  672,  671,  670,
      669,  668,  667,  666,  665,  664,  663,  662,  661,  660,
      659,  658,  657,  623,  622,  621,  618,  617,  616,  615,
      614,  613,  612,  611,  610,  609,  608,  607,  606,  605,
      604,  603,  602,  601,  600,  599,  598,  597,  596,  595,
      594,  593,  592,  591,  590,  589,  588,  587,  586,  585,
      584,  578,  577,  537,  532,  531,  530,  529,  528,  527,
      526,  525,  524,  523,  522,  521,  520,  519,  518,  517,

      516,  515,  514,  513,  512,  511,  510,  509,  508,  507,
      506,  505,  504,  503,  502,  501,  500,  499,  498,  497,
      496,  455,  454,  453,  452,  451,  450,  449,  448,  445,
      444,  443,  442,  441,  440,  439,  438,  437,  436,  435,
      434,  433,  432,  431,  430,  429,  428,  427,  426,  425,
      424,  423,  422,  421,  420,  419,  418,  417,  416,  382,
      381,  362,  361,  360,  359,  358,  357,  356,  355,  352,
      349,  348,  347,  346,  345,  341,  340,  339,  336,  335,
      331,  330,  329,  323,  322,  180,  235,  177,  259,  152,
      258,  257,  254,  244,  240,  231,  230, 1189, 1189,  180,

      177,  153,  152,  130,   95, 1189, 1189,   73,   47,   11,
     1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189,
     1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189,
     1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189,
     1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189,
     1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189,
     1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189,
     1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189
    } ;

static yyconst flex_int16_t yy_chk[2880] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    2,
        4,    4,    5,    2,    4,    6,    8,   15, 1102,    5,
        8,   10,    6,    7,   19,   10,   16,   10,   19,   17,
       16,   17,   17,   23,   23,   23,  147,    7,   18,   18,

       18,   18,   18, 1103,   24,   24,   24,   25,   25,   25,
      147,    7,   26,   26,   26,   15,   44,   82,   82,    7,
       44,    7,    7, 1108,    7,    7,   16,    7,    7,    7,
       24,    7,    7,    7,    7,    7,    7,    7,   20,   48,
       20,   20,   71,   48,   26,   74,   71,   20,   20,   74,
       27,   27,   27,  453,   20,   28,   28,   28,  453,   29,
       29,   29,   25,   20,   27,   30,   30,   30,   31,   31,
       31,   32,   32,   32,   20,   20,   33,   33,   33, 1109,
       20,   34,   34,   34,   35,   35,   35,   84,   20,   84,
       76,   20,   36,   36,   36,   37,   37,   37,   87,   29,

       87,   28,   29,  454,   32,   29,   79,   38,   38,   38,
       79,   30,   32,   31,   32,  139,  454,   35,   39,   39,
       39,   33,   31,   40,   40,   40,  230,   34,   76, 1111,
       35,   41,   41,   41,   42,   42,   42,  230,  133,   36,
       55,   55,   55,   37,  139,   81,   37,   38,   38,   81,
       38,   56,   56,   56,  133,   39,  243,   38,   39,   54,
       54,   54,  243,   58,   58,   58,   39,  131,   40,   42,
      243,  131,   41,   39,   57,   57,   57,   41,   45,   45,
       45,   45,   45,   45,   45,   45,   45,  138,   55,   45,
       45,  138,   54,   45,   56,   45,   45,   45,   45,   45,

       58,   59,   59,   59,   60,   60,   60,   57,   81,   58,
       61,   61,   61, 1112,   57,  145,  183,   57,  183,  145,
       57,   62,   62,   62,   63,   63,   63,   64,   64,   64,
       65,   65,   65, 1113,   59,   66,   66,   66,   67,   67,
       67,   60,   59, 1092,   59,  136,   61,   59,   68,   68,
       68,   70,   70,   70,  136,   61, 1092,   63,   62,  185,
       64,  185,   69,   69,   69,   63,   85,   85,   85,  144,
       63,  144,  235,   64,  144,   67,  144,   65,   65,   96,
       96,   96, 1114,   66,  235,   68,   66,  235,   68,   68,
       66,   68,   97,   97,   97, 1116,   70,  150,   68,   69,

       70,  150,   69,   69,   86, 1117,   86,   86,   86,   97,
       69,   90,   90,  137,   86,   86, 1118,   69,   90,   90,
       91,   91,  137,  180,   91,   91,   98,   98,   98,   99,
       99,   99,  180,  100,  100,  100,  101,  101,  101,  175,
      178,   86,   86,  175,  178,   90,   90,  102,  102,  102,
      103,  103,  103,   99,  100,  104,  104,  104,   98,  105,
      105,  105,  106,  106,  106,  107,  107,  107,  108,  108,
      108,  109,  109,  109,  110,  110,  110,  111,  111,  111,
      102,  251,  101,  103,  112,  112,  112,  113,  113,  113,
      251,  114,  114,  114, 1119,  115,  115,  115,  188,  188,

      104,  116,  116,  116,  117,  117,  117,  118,  118,  118,
      105,  108,  107,  106,  806,  806,  109,  119,  119,  119,
      110,  120,  120,  120,  121,  121,  121,  111,  114,  112,
      141,  113,  115,  122,  122,  122,  141,  141,  117,  123,
      123,  123,  116,  124,  124,  124, 1120,  116,  125,  125,
      125,  231,  231,  118,  231, 1121,  119,  121,  126,  126,
      126,  127,  127,  127,  128,  128,  128,  120,  129,  129,
      129,  143,  121,  119,  702,  143,  702,  122,  154,  154,
      154,  155,  155,  155,  143, 1122,  238,  123,  156,  156,
      156,  157,  157,  157,  124,  125,  159,  159,  159,  126,

      158,  158,  158,  238, 1123,  128,  666,  126,  129,  127,
      160,  160,  160,  161,  161,  161,  162,  162,  162, 1124,
      666,  154,  163,  163,  163,  249,  164,  164,  164,  353,
      748,  156,  155,  353,  157,  165,  165,  165,  158,  166,
      166,  166,  748,  249,  159,  167,  167,  167,  168,  168,
      168,  169,  169,  169,  170,  170,  170,  171,  171,  171,
      160,  164,  172,  172,  172, 1125, 1129,  163,  173,  173,
      173,  162,  174,  174,  174, 1130,  166,  182,  182,  165,
      168,  167,  534, 1131,  182,  182,  534,  184,  184,  166,
      184,  184,  184, 1132,  835,  169,  171,  191,  191,  191,

      606,  835,  189,  189,  170,  606,  172, 1133, 1134,  174,
      189,  182,  182,  171,  191,  173,  181,  187,  187, 1135,
      181,  195,  195,  195,  187,  187, 1136, 1138,  181,  181,
     1140,  181,  181,  181,  181,  181,  181,  189,  192,  192,
      192,  194,  194,  194,  196,  196,  196,  197,  197,  197,
     1141,  187,  187,  193,  193,  193,  668,  668,  181,  181,
      181,  181,  181,  181,  195,  668, 1142,  193, 1144, 1149,
      193,  668, 1152,  194,  198,  198,  198, 1153,  192,  199,
      199,  199,  200,  200,  200, 1154, 1155,  192,  201,  201,
      201, 1156,  196,  202,  202,  202,  197,  203,  203,  203,

      204,  204,  204,  205,  205,  205,  206,  206,  206,  207,
      207,  207, 1157,  199,  208,  208,  208,  209,  209,  209,
      210,  210,  210,  198, 1163, 1164,  200,  211,  211,  211,
      203,  201, 1165,  204, 1167,  212,  212,  212,  213,  213,
      213, 1168,  202, 1172, 1173,  206,  207,  214,  214,  214,
      215,  215,  215,  216,  216,  216,  217,  217,  217,  218,
      218,  218,  219,  219,  219,  209, 1174, 1179,  208,  220,
      220,  220,  210, 1182,  221,  221,  221,  211,  212,  222,
      222,  222,  223,  223,  223, 1184,  213,  215,  224,  224,
      224, 1197,  214,  225,  225,  225,  226,  226,  226, 1101,

      227,  227,  227,  216, 1100, 1099,  217, 1097, 1095,  219,
      218,  221,  260,  260,  260,  220,  222,  261,  261,  261,
      262,  262,  262,  263,  263,  263, 1094, 1091,  223,  224,
     1090, 1089,  226,  227,  264,  264,  264,  265,  265,  265,
      266,  266,  266,  225,  267,  267,  267,  268,  268,  268,
     1088, 1087,  262, 1086,  261,  269,  269,  269,  270,  270,
      270,  260,  271,  271,  271, 1085,  263,  264,  272,  272,
      272,  273,  273,  273, 1084,  274,  274,  274,  275,  275,
      275,  265,  276,  276,  276, 1078,  268,  277,  277,  277,
     1077, 1075,  269, 1074, 1073,  270, 1072,  267,  278,  278,

      278, 1071, 1070,  271, 1069,  272,  279,  279,  279,  282,
     1068,  282,  282,  282,  283, 1067,  283,  283,  283, 1064,
      273,  274, 1063, 1062,  277,  283, 1061,  276,  284,  284,
      284,  285,  285,  285, 1059,  278, 1058, 1057,  279,  286,
      286,  286,  287,  287,  287,  288,  288,  288,  289,  289,
      289, 1056,  283, 1055,  287,  290,  290,  290,  291,  291,
      291,  292,  292,  292,  285,  288,  293,  293,  293,  289,
     1046, 1045,  289, 1044,  294,  294,  294,  295,  295,  295,
      296,  296,  296,  297,  297,  297, 1043, 1041,  286,  298,
      298,  298,  299,  299,  299,  300,  300,  300,  301,  301,

      301,  302,  302,  302,  303,  303,  303,  304,  304,  304,
      292,  305,  305,  305, 1040, 1039,  293,  294, 1038, 1036,
      297,  296,  306,  306,  306,  307,  307,  307,  308,  308,
      308, 1035,  298,  310,  310,  310,  302,  303, 1034, 1033,
      304, 1032,  299, 1031,  309,  309,  309,  301,  305,  311,
      311,  311,  312,  312,  312,  313,  313,  313,  314,  314,
      314,  308, 1030,  306, 1029,  308,  315,  315,  315,  316,
      316,  316,  317,  317,  317,  307,  309,  318,  318,  318,
     1028, 1027,  310,  319,  319,  319, 1026,  312, 1025, 1024,
      311,  320,  320,  320,  321,  321,  321, 1023,  313,  363,

      363,  363,  364,  364,  364,  316,  365,  365,  365, 1022,
     1021,  314,  366,  366,  366, 1020,  318,  317,  367,  367,
      367, 1011,  368,  368,  368,  369,  369,  369,  370,  370,
      370,  371,  371,  371,  319, 1010,  363,  372,  372,  372,
     1009, 1008,  321, 1007,  366,  373,  373,  373,  374,  374,
      374,  375,  375,  375,  365,  368,  376,  376,  376, 1005,
      377,  377,  377,  378,  378,  378,  379,  379,  379,  367,
     1004,  369,  380,  380,  380, 1003,  371, 1002, 1000,  370,
      383,  383,  383,  384,  384,  384,  372,  385,  385,  385,
      999,  373,  998,  377,  997,  996,  374,  377,  995,  994,

      375,  993,  379,  992,  991,  380,  385,  990,  376,  386,
      386,  386,  378,  989,  988,  380,  387,  387,  387,  388,
      388,  388,  987,  986,  384,  389,  389,  389,  985,  383,
      390,  390,  390,  984,  386,  391,  391,  391,  392,  392,
      392,  983,  973,  388,  972,  387,  393,  393,  393,  394,
      394,  394,  395,  395,  395,  396,  396,  396,  397,  397,
      397,  398,  398,  398,  399,  399,  399,  971,  400,  400,
      400,  970,  391,  392,  401,  401,  401,  402,  402,  402,
      403,  403,  403,  404,  404,  404,  405,  405,  405,  406,
      406,  406,  407,  407,  407,  397,  408,  408,  408,  409,

      409,  409,  396,  400,  410,  410,  410,  968,  967,  401,
      966,  398,  965,  964,  399,  411,  411,  411,  962,  404,
      412,  412,  412,  403,  413,  413,  413,  407,  414,  414,
      414,  961,  409,  415,  415,  415,  405,  456,  456,  456,
      457,  457,  457,  458,  458,  458,  408,  459,  459,  459,
      960,  959,  411,  460,  460,  460,  461,  461,  461,  958,
      957,  414,  462,  462,  462,  415,  463,  463,  463,  413,
      465,  465,  465,  457,  464,  464,  464,  466,  466,  466,
      467,  467,  467,  468,  468,  468,  469,  469,  469,  956,
      459,  955,  458,  954,  953,  462,  470,  470,  470,  471,

      471,  471,  952,  460,  461,  472,  472,  472,  473,  473,
      473,  475,  475,  475,  951,  463,  950,  467,  466,  464,
      949,  474,  474,  474,  948,  947,  468,  474,  477,  477,
      477,  946,  945,  468,  944,  475,  469,  478,  478,  478,
      471,  943,  477,  933,  470,  472,  479,  479,  479,  932,
      480,  480,  480,  481,  481,  481,  482,  482,  482,  483,
      483,  483,  931,  930,  473,  476,  476,  476,  484,  484,
      484,  929,  476,  476,  476,  476,  485,  485,  485,  486,
      486,  486,  476,  480,  928,  476,  926,  479,  925,  476,
      476,  487,  487,  487,  924,  923,  483,  488,  488,  488,

      481,  922,  482,  489,  489,  489,  490,  490,  490,  491,
      491,  491,  492,  492,  492,  493,  493,  493,  484,  494,
      494,  494,  495,  495,  495,  498,  498,  921,  486,  538,
      538,  538,  539,  539,  539,  540,  540,  540,  541,  541,
      541,  498,  498,  542,  542,  542,  498,  543,  543,  543,
      492,  920,  493,  544,  544,  544,  545,  545,  545,  491,
      919,  917,  494,  546,  546,  546,  547,  547,  547,  916,
      538,  915,  495,  548,  548,  548,  549,  549,  549,  542,
      552,  552,  552,  539,  914,  540,  543,  913,  912,  545,
      544,  550,  550,  550,  551,  551,  551,  911,  547,  553,

      553,  553,  910,  554,  554,  554,  555,  555,  555,  549,
      909,  908,  552,  556,  556,  556,  557,  557,  557,  546,
      554,  907,  557,  906,  548,  905,  558,  558,  558,  904,
      550,  559,  559,  559,  903,  902,  553,  901,  551,  556,
      558,  560,  560,  560,  561,  561,  561,  562,  562,  562,
      559,  561,  563,  563,  563,  560,  564,  564,  564,  565,
      565,  565,  889,  888,  562,  566,  566,  566,  567,  567,
      567,  568,  568,  568,  569,  569,  569,  887,  563,  886,
      885,  563,  884,  570,  570,  570,  564,  571,  571,  571,
      572,  572,  572,  573,  573,  573,  574,  574,  574,  883,

      566,  575,  575,  575,  576,  576,  576,  882,  881,  565,
      624,  624,  624,  625,  625,  625,  880,  878,  567,  568,
      570,  626,  626,  626,  627,  627,  627,  572,  628,  628,
      628,  874,  574,  629,  629,  629,  630,  630,  630,  631,
      631,  631,  632,  632,  632,  633,  633,  633,  634,  634,
      634,  873,  872,  626,  871,  870,  627,  869,  868,  624,
      625,  635,  635,  635,  867,  628,  636,  636,  636,  866,
      629,  637,  637,  637,  865,  864,  631,  863,  862,  630,
      861,  638,  638,  638,  860,  632,  639,  639,  639,  640,
      640,  640,  634,  633,  641,  641,  641,  642,  642,  642,

      640,  643,  643,  643,  859,  642,  858,  636,  857,  856,
      639,  641,  635,  638,  644,  644,  644,  645,  645,  645,
      855,  637,  646,  646,  646,  854,  853,  643,  647,  647,
      647,  836,  645,  648,  648,  648,  646,  834,  644,  833,
      649,  649,  649,  650,  650,  650,  651,  651,  651,  647,
      649,  652,  652,  652,  648,  653,  653,  653,  654,  654,
      654,  655,  655,  655,  656,  656,  656,  703,  703,  703,
      704,  704,  704,  705,  705,  705,  706,  706,  706,  707,
      707,  707,  832,  651,  708,  708,  708,  709,  709,  709,
      710,  710,  710,  831,  654,  711,  711,  711,  829,  828,

      705,  712,  712,  712,  703,  827,  825,  704,  824,  706,
      713,  713,  713,  823,  714,  714,  714,  715,  715,  715,
      822,  821,  710,  716,  716,  716,  717,  717,  717,  718,
      718,  718,  711,  719,  719,  719,  820,  819,  712,  720,
      720,  720,  818,  817,  719,  721,  721,  721,  722,  722,
      722,  816,  723,  723,  723,  815,  720,  713,  714,  724,
      724,  724,  814,  725,  725,  725,  722,  715,  813,  724,
      721,  725,  726,  726,  726,  810,  717,  723,  727,  727,
      727,  728,  728,  728,  729,  729,  729,  809,  727,  726,
      730,  730,  730,  775,  775,  775,  776,  776,  776,  777,

      777,  777,  778,  778,  778,  779,  779,  779,  780,  780,
      780,  808,  807,  728,  781,  781,  781,  782,  782,  782,
      783,  783,  783,  805,  804,  775,  784,  784,  784,  785,
      785,  785,  786,  786,  786,  803,  802,  787,  787,  787,
      777,  780,  786,  787,  776,  788,  788,  788,  801,  800,
      778,  789,  789,  789,  799,  779,  798,  783,  790,  790,
      790,  797,  796,  784,  791,  791,  791,  792,  792,  792,
      774,  773,  791,  793,  793,  793,  772,  792,  794,  794,
      794,  770,  769,  793,  795,  795,  795,  837,  837,  837,
      838,  838,  838,  839,  839,  839,  840,  840,  840,  841,

      841,  841,  842,  842,  842,  843,  843,  843,  766,  795,
      844,  844,  844,  845,  845,  845,  846,  846,  846,  847,
      847,  847,  838,  846,  848,  848,  848,  849,  849,  849,
      765,  841,  763,  762,  837,  840,  845,  761,  842,  760,
      759,  839,  758,  757,  847,  756,  844,  850,  850,  850,
      843,  890,  890,  890,  891,  891,  891,  892,  892,  892,
      893,  893,  893,  894,  894,  894,  755,  895,  895,  895,
      896,  896,  896,  897,  897,  897,  898,  898,  898,  899,
      899,  899,  900,  900,  900,  934,  934,  934,  935,  935,
      935,  936,  936,  936,  754,  891,  899,  753,  894,  937,

      937,  937,  938,  938,  938,  897,  890,  892,  895,  752,
      751,  893,  939,  939,  939,  750,  749,  934,  747,  746,
      896,  940,  940,  940,  745,  941,  941,  941,  942,  942,
      942,  744,  743,  935,  974,  974,  974,  742,  942,  975,
      975,  975,  936,  937,  741,  938,  976,  976,  976,  977,
      977,  977,  740,  940,  978,  978,  978,  939,  941,  979,
      979,  979,  980,  980,  980,  981,  981,  981,  982,  982,
      982,  974, 1012, 1012, 1012, 1013, 1013, 1013,  739,  976,
      975, 1014, 1014, 1014,  738,  737,  977, 1015, 1015, 1015,
      736,  978,  735,  734, 1016, 1016, 1016,  733,  979, 1017,

     1017, 1017, 1018, 1018, 1018,  732,  731,  980, 1019, 1019,
     1019,  701,  981, 1047, 1047, 1047, 1048, 1048, 1048, 1049,
     1049, 1049,  700,  699, 1014, 1013, 1012, 1016,  698, 1049,
      697,  696, 1015,  694,  693, 1018, 1050, 1050, 1050, 1051,
     1051, 1051,  692, 1052, 1052, 1052,  691,  690, 1047, 1019,
     1053, 1053, 1053, 1079, 1079, 1079, 1080, 1080, 1080, 1081,
     1081, 1081, 1082, 1082, 1082, 1083, 1083, 1083, 1104, 1104,
     1104, 1105, 1105, 1105, 1106, 1106, 1106, 1107, 1107, 1107,
     1126, 1126, 1126,  689, 1051,  688, 1050, 1052,  687,  686,
     1079, 1127, 1127, 1127, 1128, 1128, 1128, 1145, 1145, 1145,

      685,  684, 1083,  683, 1080, 1146, 1146, 1146, 1081, 1160,
     1160, 1160, 1161, 1161, 1161, 1104, 1169, 1169, 1169, 1105,
      681, 1170, 1170, 1170,  680, 1161, 1107, 1176, 1176, 1176,
     1126, 1177, 1177, 1177, 1181, 1181, 1181, 1127, 1145, 1183,
     1183, 1183, 1185, 1185, 1185, 1187, 1187, 1187, 1188, 1188,
     1188,  678,  676, 1146, 1170, 1160,  675,  674,  671,  670,
      669, 1169,  665,  664,  663,  662,  661,  660,  659,  658,
     1181,  657,  623,  622,  621,  620, 1177,  619,  618, 1185,
      617,  616, 1183,  615,  614,  613,  612,  611,  610,  608,
      607,  605,  604, 1187, 1190, 1190, 1190, 1190, 1191, 1191,

     1191, 1191, 1192, 1192, 1192, 1192, 1193, 1193, 1193, 1193,
     1194, 1194, 1195, 1195, 1196,  603, 1196, 1196,  602,  601,
      600,  598,  597,  596,  595,  594,  593,  592,  591,  590,
      589,  588,  587,  586,  585,  584,  583,  582,  581,  580,
      579,  578,  577,  537,  536,  535,  533,  532,  531,  530,
      529,  528,  527,  526,  525,  524,  523,  522,  521,  520,
      519,  518,  517,  516,  515,  514,  513,  512,  511,  510,
      509,  508,  507,  506,  505,  504,  503,  502,  501,  500,
      499,  497,  496,  455,  452,  451,  450,  449,  448,  447,
      446,  445,  444,  443,  442,  441,  440,  439,  438,  437,

      436,  435,  434,  433,  432,  431,  430,  429,  428,  427,
      426,  425,  424,  423,  422,  421,  420,  419,  418,  417,
      416,  361,  360,  359,  358,  357,  356,  355,  354,  352,
      351,  350,  349,  348,  347,  346,  345,  344,  343,  342,
      341,  340,  339,  338,  337,  336,  335,  334,  333,  332,
      330,  329,  328,  327,  326,  325,  324,  323,  322,  281,
      280,  259,  258,  257,  256,  255,  254,  253,  252,  250,
      248,  247,  246,  245,  244,  242,  240,  239,  237,  236,
      234,  233,  232,  229,  228,  179,  177,  176,  152,  151,
      149,  148,  146,  142,  140,  135,  134,   83,   78,   75,

       72,   52,   49,   43,   22,   21,   11,    9,    3, 1189,
     1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189,
     1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189,
     1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189,
     1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189,
     1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189,
     1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189,
     1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189
    } ;

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int yy_flex_debug;
int yy_flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *yytext;
#line 1 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
/*
 * The SIP lexer.
 *
 * Copyright (c) 2020 Riverbank Computing Limited <info@riverbankcomputing.com>
 *
 * This file is part of SIP.
 *
 * This copy of SIP is licensed for use under the terms of the SIP License
 * Agreement.  See the file LICENSE for more details.
 *
 * This copy of SIP may also used under the terms of the GNU General Public
 * License v2 or v3 as published by the Free Software Foundation which can be
 * found in the files LICENSE-GPL2 and LICENSE-GPL3 included in this package.
 *
 * SIP is supplied WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 */
#line 20 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <errno.h>

#include "sip.h"
#include "parser.h"


#ifndef FLEX_SCANNER
#error "Only flex is supported at the moment"
#endif


/* Windows doesn't have unistd.h so declare it here. */
extern int isatty(int);


/* These are unused. */
static int input(void) SIP_UNUSED;
static void yy_fatal_error(yyconst char *) SIP_UNUSED;
static int yy_top_state(void) SIP_UNUSED;
static void yyunput(int, char *) SIP_UNUSED;

#define YY_NO_UNISTD_H
#define YY_FATAL_ERROR(s)       fatallex(s)

#define MAX_INCLUDE_DEPTH       10
#define MAX_CODE_LINE_LENGTH    1000


static struct inputFile {
    sourceLocation sloc;                /* The source location. */
    YY_BUFFER_STATE bs;                 /* The flex buffer state handle. */
    char *cwd;                          /* The path part of the file name. */
    parserContext pc;                   /* The parser context. */
} inputFileStack[MAX_INCLUDE_DEPTH];

static int currentFile;                 /* Index of the current input file. */
static char codeLine[MAX_CODE_LINE_LENGTH + 2]; /* The current code line. */
static int codeIdx;                     /* Index of next code character. */
static int parenDepth;                  /* The current depth of (...). */
static stringList *allFiles;            /* The list of all input files. */

static FILE *openFile(const char *);
static void fatallex(char *);




#line 1546 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/lexer.c"

#define INITIAL 0
#define code 1
#define ccomment 2
#define directive 3
#define directive_start 4

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals (void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy (void );

int yyget_debug (void );

void yyset_debug (int debug_flag  );

YY_EXTRA_TYPE yyget_extra (void );

void yyset_extra (YY_EXTRA_TYPE user_defined  );

FILE *yyget_in (void );

void yyset_in  (FILE * in_str  );

FILE *yyget_out (void );

void yyset_out  (FILE * out_str  );

yy_size_t yyget_leng (void );

char *yyget_text (void );

int yyget_lineno (void );

void yyset_lineno (int line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap (void );
#else
extern int yywrap (void );
#endif
#endif

    static void yyunput (int c,char *buf_ptr  );
    
#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * );
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (void );
#else
static int input (void );
#endif

#endif

        static int yy_start_stack_ptr = 0;
        static int yy_start_stack_depth = 0;
        static int *yy_start_stack = NULL;
    
    static void yy_push_state (int new_state );
    
    static void yy_pop_state (void );
    
    static int yy_top_state (void );
    
/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#define YY_READ_BUF_SIZE 8192
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO fwrite( yytext, yyleng, 1, yyout )
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		yy_size_t n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, yyin))==0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex (void);

#define YY_DECL int yylex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK break;
#endif

#define YY_RULE_SETUP \
	if ( yyleng > 0 ) \
		YY_CURRENT_BUFFER_LVALUE->yy_at_bol = \
				(yytext[yyleng - 1] == '\n'); \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	register yy_state_type yy_current_state;
	register char *yy_cp, *yy_bp;
	register int yy_act;
    
#line 75 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"


#line 1748 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/lexer.c"

	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer(yyin,YY_BUF_SIZE );
		}

		yy_load_buffer_state( );
		}

	while ( 1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of yytext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
		yy_current_state += YY_AT_BOL();
yy_match:
		do
			{
			register YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)];
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 1190 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 2810 );

yy_find_action:
		yy_act = yy_accept[yy_current_state];
		if ( yy_act == 0 )
			{ /* have to back up */
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			yy_act = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
YY_RULE_SETUP
#line 77 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{BEGIN directive_start; return TK_AUTOPYNAME;}
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 78 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{BEGIN directive_start; return TK_COMPOMODULE;}
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 79 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{BEGIN directive_start; return TK_DEFDOCSTRFMT;}
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 80 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{BEGIN directive_start; return TK_DEFDOCSTRSIG;}
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 81 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{BEGIN directive_start; return TK_DEFENCODING;}
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 82 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{BEGIN directive_start; return TK_DEFMETATYPE;}
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 83 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{BEGIN directive_start; return TK_DEFSUPERTYPE;}
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 84 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{return TK_END;}
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 85 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{BEGIN INITIAL; return TK_END;}
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 86 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{return TK_EXCEPTION;}
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 87 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{BEGIN directive_start; return TK_FEATURE;}
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 88 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{BEGIN directive_start; return TK_HIDE_NS;}
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 89 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{return TK_IF;}
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 90 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{BEGIN directive_start; return TK_IMPORT;}
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 91 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{BEGIN directive_start; return TK_INCLUDE;}
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 92 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{BEGIN directive_start; return TK_LICENSE;}
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 93 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{return TK_MAPPEDTYPE;}
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 94 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{BEGIN directive_start; return TK_MODULE;}
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 95 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{return TK_PLATFORMS;}
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 96 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{BEGIN directive_start; return TK_PLUGIN;}
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 97 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{BEGIN directive_start; return TK_PROPERTY;}
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 98 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{return TK_TIMELINE;}
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 100 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{return TK_CLASS;}
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 101 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{return TK_STRUCT;}
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 102 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{return TK_UNION;}
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 103 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{return TK_PUBLIC;}
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 104 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{return TK_PROTECTED;}
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 105 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{return TK_PRIVATE;}
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 106 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{return TK_SIGNALS;}
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 107 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{return TK_SIGNALS;}
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 108 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{return TK_SIGNAL_METHOD;}
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 109 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{return TK_SLOTS;}
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 110 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{return TK_SLOTS;}
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 111 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{return TK_SLOT_METHOD;}
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 112 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{return TK_CHAR;}
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 113 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{return TK_WCHAR_T;}
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 114 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{return TK_BOOL;}
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 115 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{return TK_SHORT;}
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 116 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{return TK_INT;}
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 117 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{return TK_LONG;}
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 118 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{return TK_FLOAT;}
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 119 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{return TK_DOUBLE;}
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 120 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{return TK_VOID;}
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 121 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{return TK_VIRTUAL;}
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 122 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{return TK_ENUM;}
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 123 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{return TK_SIGNED;}
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 124 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{return TK_UNSIGNED;}
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 125 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{return TK_CONST;}
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 126 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{return TK_STATIC;}
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 127 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{return TK_TRUE_VALUE;}
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 128 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{return TK_FALSE_VALUE;}
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 129 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{return TK_NULL_VALUE;}
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 130 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{return TK_TYPEDEF;}
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 131 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{return TK_NAMESPACE;}
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 132 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{return TK_OPERATOR;}
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 133 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{return TK_THROW;}
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 134 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{return TK_NOEXCEPT;}
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 135 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{return TK_EXPLICIT;}
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 136 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{return TK_TEMPLATE;}
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 137 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{return TK_FINAL;}
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 138 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{return TK_SIZET;}
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 139 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{return TK_SCOPE;}
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 140 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{return TK_LOGICAL_OR;}
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 141 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{return TK_ELLIPSIS;}
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 142 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{return TK_PYOBJECT;}
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 143 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{return TK_PYTUPLE;}
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 144 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{return TK_PYLIST;}
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 145 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{return TK_PYDICT;}
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 146 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{return TK_PYCALLABLE;}
	YY_BREAK
case 70:
YY_RULE_SETUP
#line 147 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{return TK_PYSLICE;}
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 148 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{return TK_PYTYPE;}
	YY_BREAK
case 72:
YY_RULE_SETUP
#line 149 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{return TK_PYBUFFER;}
	YY_BREAK
case 73:
YY_RULE_SETUP
#line 150 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{return TK_PYENUM;}
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 151 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{return TK_PYHASHT;}
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 152 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{return TK_PYSSIZET;}
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 154 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{
    /*
     * Remove in v7.0.  It should have been removed in v6.0 but we accidentally
     * left some occurences in PyQt5.
     */
    return TK_PYSSIZET;
}
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 162 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{return TK_FORMAT;}
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 163 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{return TK_GET;}
	YY_BREAK
case 79:
YY_RULE_SETUP
#line 164 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{return TK_ID;}
	YY_BREAK
case 80:
YY_RULE_SETUP
#line 165 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{return TK_KWARGS;}
	YY_BREAK
case 81:
YY_RULE_SETUP
#line 166 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{return TK_LANGUAGE;}
	YY_BREAK
case 82:
YY_RULE_SETUP
#line 167 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{return TK_LICENSEE;}
	YY_BREAK
case 83:
YY_RULE_SETUP
#line 168 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{return TK_NAME;}
	YY_BREAK
case 84:
YY_RULE_SETUP
#line 169 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{return TK_OPTIONAL;}
	YY_BREAK
case 85:
YY_RULE_SETUP
#line 170 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{return TK_ORDER;}
	YY_BREAK
case 86:
YY_RULE_SETUP
#line 171 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{return TK_REMOVELEADING;}
	YY_BREAK
case 87:
YY_RULE_SETUP
#line 172 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{return TK_SET;}
	YY_BREAK
case 88:
YY_RULE_SETUP
#line 173 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{return TK_SIGNATURE;}
	YY_BREAK
case 89:
YY_RULE_SETUP
#line 174 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{return TK_TIMESTAMP;}
	YY_BREAK
case 90:
YY_RULE_SETUP
#line 175 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{return TK_TYPE;}
	YY_BREAK
case 91:
YY_RULE_SETUP
#line 176 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{return TK_USEARGNAMES;}
	YY_BREAK
case 92:
YY_RULE_SETUP
#line 177 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{return TK_PYSSIZETCLEAN;}
	YY_BREAK
case 93:
YY_RULE_SETUP
#line 178 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{return TK_USELIMITEDAPI;}
	YY_BREAK
case 94:
YY_RULE_SETUP
#line 179 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{return TK_ALLRAISEPYEXC;}
	YY_BREAK
case 95:
YY_RULE_SETUP
#line 180 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{return TK_CALLSUPERINIT;}
	YY_BREAK
case 96:
YY_RULE_SETUP
#line 181 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{return TK_DEFERRORHANDLER;}
	YY_BREAK
case 97:
YY_RULE_SETUP
#line 183 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{return TK_TRUE_VALUE;}
	YY_BREAK
case 98:
YY_RULE_SETUP
#line 184 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{return TK_FALSE_VALUE;}
	YY_BREAK
case 99:
YY_RULE_SETUP
#line 187 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{
    /* Ignore whitespace. */
    ;
}
	YY_BREAK
case 100:
YY_RULE_SETUP
#line 192 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{
    /*
     * Maintain the parenthesis depth so that we don't enter the 'code' state
     * until any arguments have been parsed.
     */
    ++parenDepth;

    BEGIN directive;

    return '(';
}
	YY_BREAK
case 101:
YY_RULE_SETUP
#line 204 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{
    /* Maintain the parenthesis depth. */
    --parenDepth;

    BEGIN INITIAL;

    return ')';
}
	YY_BREAK
case 102:
/* rule 102 can match eol */
YY_RULE_SETUP
#line 213 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{
    /* Maintain the line number. */
    ++inputFileStack[currentFile].sloc.linenr;

    if (codeIdx == 0 && parenDepth == 0)
    {
        BEGIN code;
    }
}
	YY_BREAK
case 103:
YY_RULE_SETUP
#line 223 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{
    /* Ignore C++ style comments. */
    ;
}
	YY_BREAK
case 104:
YY_RULE_SETUP
#line 229 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{
    /* A signed decimal number. */
    yylval.number = strtol(yytext,NULL,0);
    return TK_NUMBER_VALUE;
}
	YY_BREAK
case 105:
YY_RULE_SETUP
#line 236 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{
    /* A floating point number. */
    yylval.real = strtod(yytext,NULL);
    return TK_REAL_VALUE;
}
	YY_BREAK
case 106:
YY_RULE_SETUP
#line 243 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{
    /* An unsigned hexadecimal number. */
    yylval.number = strtol(yytext,NULL,16);
    return TK_NUMBER_VALUE;
}
	YY_BREAK
case 107:
YY_RULE_SETUP
#line 250 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{
    /* An identifier name. */
    yylval.text = sipStrdup(yytext);
    return TK_NAME_VALUE;
}
	YY_BREAK
case 108:
YY_RULE_SETUP
#line 257 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{
    /* A relative pathname. */
    yylval.text = sipStrdup(yytext);
    return TK_PATH_VALUE;
}
	YY_BREAK
case 109:
/* rule 109 can match eol */
YY_RULE_SETUP
#line 264 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{
    /* A double-quoted string. */
    char ch, *dp, *sp;

    /*
     * Copy the string without the quotes and interpret any standard escape
     * characters.
     */
    yylval.text = sipMalloc(strlen(yytext) - 2 + 1);

    dp = yylval.text;
    sp = yytext + 1;

    while ((ch = *sp++) != '"' && ch != '\0')
    {
        if (ch == '\\')
        {
            ch = *sp++;

            if (ch == 'n')
                ch = '\n';
            else if (ch == 'r')
                ch = '\r';
            else if (ch == 't')
                ch = '\t';
        }

        *dp++ = ch;
    }

    *dp = '\0';

    return TK_STRING_VALUE;
}
	YY_BREAK
case 110:
YY_RULE_SETUP
#line 300 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{
    /* A single-quoted hex encoded character. */
    yylval.qchar = strtol(&yytext[3], NULL, 16);

    return TK_QCHAR_VALUE;
}
	YY_BREAK
case 111:
/* rule 111 can match eol */
YY_RULE_SETUP
#line 308 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{
    /* A single-quoted character. */
    if (strlen(yytext) != 3)
        fatallex("Exactly one character expected between single quotes");

    yylval.qchar = yytext[1];

    return TK_QCHAR_VALUE;
}
	YY_BREAK
case 112:
YY_RULE_SETUP
#line 319 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{
    /* Ignore C-style comments. */
    yy_push_state(ccomment);
}
	YY_BREAK
case 113:
/* rule 113 can match eol */
YY_RULE_SETUP
#line 323 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{
    ++inputFileStack[currentFile].sloc.linenr;
}
	YY_BREAK
case 114:
YY_RULE_SETUP
#line 326 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{
    yy_pop_state();
}
	YY_BREAK
case 115:
YY_RULE_SETUP
#line 329 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{
    ;
}
	YY_BREAK

/*
 * Remove these in SIP v7.  They are retained (but ignored) so that PyQt5 can
 * be built with SIP v6.
 */

case 116:
YY_RULE_SETUP
#line 341 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{
    /* The start of a read buffer code block. */
    codeIdx = 0;
    return TK_READBUFFERCODE;
}
	YY_BREAK
case 117:
YY_RULE_SETUP
#line 347 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{
    /* The start of a write buffer code block. */
    codeIdx = 0;
    return TK_WRITEBUFFERCODE;
}
	YY_BREAK
case 118:
YY_RULE_SETUP
#line 353 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{
    /* The start of a segment count code block. */
    codeIdx = 0;
    return TK_SEGCOUNTCODE;
}
	YY_BREAK
case 119:
YY_RULE_SETUP
#line 359 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{
    /* The start of a char buffer code block. */
    codeIdx = 0;
    return TK_CHARBUFFERCODE;
}
	YY_BREAK

/* End of deprecated directives. */

case 120:
YY_RULE_SETUP
#line 370 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{
    /* The software license. */
    codeIdx = 0;
    return TK_COPYING;
}
	YY_BREAK
case 121:
YY_RULE_SETUP
#line 376 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{
    /* The start of a from-type code block. */
    codeIdx = 0;
    return TK_FROMTYPE;
}
	YY_BREAK
case 122:
YY_RULE_SETUP
#line 382 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{
    /* The start of a to-type code block. */
    codeIdx = 0;
    return TK_TOTYPE;
}
	YY_BREAK
case 123:
YY_RULE_SETUP
#line 388 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{
    /* The start of a release code block. */
    codeIdx = 0;
    return TK_RELEASE;
}
	YY_BREAK
case 124:
YY_RULE_SETUP
#line 394 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{
    /* The start of a to-sub-class code block. */
    codeIdx = 0;
    return TK_TOSUBCLASS;
}
	YY_BREAK
case 125:
YY_RULE_SETUP
#line 400 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{
    /* The start of an exported header code block. */
    codeIdx = 0;
    return TK_EXPHEADERCODE;
}
	YY_BREAK
case 126:
YY_RULE_SETUP
#line 406 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{
    /* The start of part of an extract. */
    codeIdx = 0;

    BEGIN directive_start;

    return TK_EXTRACT;
}
	YY_BREAK
case 127:
YY_RULE_SETUP
#line 415 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{
    /* The start of a module header code block. */
    codeIdx = 0;
    return TK_MODHEADERCODE;
}
	YY_BREAK
case 128:
YY_RULE_SETUP
#line 421 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{
    /* The start of a type header code block. */
    codeIdx = 0;
    return TK_TYPEHEADERCODE;
}
	YY_BREAK
case 129:
YY_RULE_SETUP
#line 427 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{
    /* The start of a pre-initialisation code block. */
    codeIdx = 0;
    return TK_PREINITCODE;
}
	YY_BREAK
case 130:
YY_RULE_SETUP
#line 433 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{
    /* The start of an initialisation code block. */
    codeIdx = 0;
    return TK_INITCODE;
}
	YY_BREAK
case 131:
YY_RULE_SETUP
#line 439 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{
    /* The start of a post-initialisation code block. */
    codeIdx = 0;
    return TK_POSTINITCODE;
}
	YY_BREAK
case 132:
YY_RULE_SETUP
#line 445 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{
    /* The start of a class finalisation code block. */
    codeIdx = 0;
    return TK_FINALCODE;
}
	YY_BREAK
case 133:
YY_RULE_SETUP
#line 451 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{
    /* The start of a unit code block. */
    codeIdx = 0;
    return TK_UNITCODE;
}
	YY_BREAK
case 134:
YY_RULE_SETUP
#line 457 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{
    /* The start of a unit post-include code block. */
    codeIdx = 0;
    return TK_UNITPOSTINCLUDECODE;
}
	YY_BREAK
case 135:
YY_RULE_SETUP
#line 463 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{
    /* The start of a module code block. */
    codeIdx = 0;
    return TK_MODCODE;
}
	YY_BREAK
case 136:
YY_RULE_SETUP
#line 469 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{
    /* The start of a type code block. */
    codeIdx = 0;
    return TK_TYPECODE;
}
	YY_BREAK
case 137:
YY_RULE_SETUP
#line 475 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{
    /* The start of a C++ method code block. */
    codeIdx = 0;
    return TK_METHODCODE;
}
	YY_BREAK
case 138:
YY_RULE_SETUP
#line 481 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{
    /* The start of a C++ code block to insert before the MethodCode. */
    codeIdx = 0;
    return TK_PREMETHODCODE;
}
	YY_BREAK
case 139:
YY_RULE_SETUP
#line 487 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{
    /* The start of a C++ virtual call code block. */
    codeIdx = 0;
    return TK_VIRTUALCALLCODE;
}
	YY_BREAK
case 140:
YY_RULE_SETUP
#line 493 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{
    /* The start of a C++ virtual code block. */
    codeIdx = 0;
    return TK_VIRTUALCATCHERCODE;
}
	YY_BREAK
case 141:
YY_RULE_SETUP
#line 499 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{
    /* The start of a traverse code block. */
    codeIdx = 0;
    return TK_TRAVERSECODE;
}
	YY_BREAK
case 142:
YY_RULE_SETUP
#line 505 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{
    /* The start of a clear code block. */
    codeIdx = 0;
    return TK_CLEARCODE;
}
	YY_BREAK
case 143:
YY_RULE_SETUP
#line 511 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{
    /* The start of a get buffer code block. */
    codeIdx = 0;
    return TK_GETBUFFERCODE;
}
	YY_BREAK
case 144:
YY_RULE_SETUP
#line 517 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{
    /* The start of a release buffer code block. */
    codeIdx = 0;
    return TK_RELEASEBUFFERCODE;
}
	YY_BREAK
case 145:
YY_RULE_SETUP
#line 523 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{
    /* The start of a create instance code block. */
    codeIdx = 0;
    return TK_INSTANCECODE;
}
	YY_BREAK
case 146:
YY_RULE_SETUP
#line 529 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{
    /* The start of a pickle code block. */
    codeIdx = 0;
    return TK_PICKLECODE;
}
	YY_BREAK
case 147:
YY_RULE_SETUP
#line 535 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{
    /* The start of a raise Python exception code block. */
    codeIdx = 0;
    return TK_RAISECODE;
}
	YY_BREAK
case 148:
YY_RULE_SETUP
#line 541 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{
    /* The start of an exported type hint code block. */
    codeIdx = 0;
    return TK_EXPTYPEHINTCODE;
}
	YY_BREAK
case 149:
YY_RULE_SETUP
#line 547 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{
    /* The start of a type hint code block. */
    codeIdx = 0;
    return TK_TYPEHINTCODE;
}
	YY_BREAK
case 150:
YY_RULE_SETUP
#line 553 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{
    /* The start of a docstring block. */
    codeIdx = 0;

    BEGIN directive_start;

    return TK_DOCSTRING;
}
	YY_BREAK
case 151:
YY_RULE_SETUP
#line 562 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{
    /* The start of an access code block. */
    codeIdx = 0;
    return TK_ACCESSCODE;
}
	YY_BREAK
case 152:
YY_RULE_SETUP
#line 568 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{
    /* The start of a get code block. */
    codeIdx = 0;
    return TK_GETCODE;
}
	YY_BREAK
case 153:
YY_RULE_SETUP
#line 574 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{
    /* The start of a set code block. */
    codeIdx = 0;
    return TK_SETCODE;
}
	YY_BREAK
case 154:
YY_RULE_SETUP
#line 580 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{
    /* The start of part of a virtual error handler. */
    codeIdx = 0;

    BEGIN directive_start;

    return TK_VIRTERRORHANDLER;
}
	YY_BREAK
case 155:
YY_RULE_SETUP
#line 589 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{
    /* The end of a code block. */
    BEGIN INITIAL;
    codeIdx = -1;
    return TK_END;
}
	YY_BREAK
case 156:
/* rule 156 can match eol */
YY_RULE_SETUP
#line 596 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{
    /* The end of a code line . */
    struct inputFile *ifp;

    codeLine[codeIdx] = '\n';
    codeLine[codeIdx + 1] = '\0';
    codeIdx = 0;

    ifp = &inputFileStack[currentFile];

    yylval.codeb = sipMalloc(sizeof (codeBlock));

    yylval.codeb->frag = sipStrdup(codeLine);
    yylval.codeb->linenr = ifp->sloc.linenr++;
    yylval.codeb->filename = ifp->sloc.name;

    return TK_CODELINE;
}
	YY_BREAK
case 157:
YY_RULE_SETUP
#line 615 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{
    /* The contents of a code line. */
    if (codeIdx == MAX_CODE_LINE_LENGTH)
        fatallex("Line is too long");

    codeLine[codeIdx++] = yytext[0];
}
	YY_BREAK
case 158:
YY_RULE_SETUP
#line 623 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
{
    /* Anything else is returned as is. */
    return yytext[0];
}
	YY_BREAK
case 159:
YY_RULE_SETUP
#line 628 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"
ECHO;
	YY_BREAK
#line 2949 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/lexer.c"
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(code):
case YY_STATE_EOF(ccomment):
case YY_STATE_EOF(directive):
case YY_STATE_EOF(directive_start):
	yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_c_buf_p);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( yywrap( ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	register char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	register char *source = (yytext_ptr);
	register int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr)) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			yy_size_t num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				yy_size_t new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					yyrealloc((void *) b->yy_ch_buf,b->yy_buf_size + 2  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = 0;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart(yyin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yy_size_t) ((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		yy_size_t new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	register yy_state_type yy_current_state;
	register char *yy_cp;
    
	yy_current_state = (yy_start);
	yy_current_state += YY_AT_BOL();

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		register YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 1190 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	register int yy_is_jam;
    	register char *yy_cp = (yy_c_buf_p);

	register YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 1190 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 1189);

	return yy_is_jam ? 0 : yy_current_state;
}

    static void yyunput (int c, register char * yy_bp )
{
	register char *yy_cp;
    
    yy_cp = (yy_c_buf_p);

	/* undo effects of setting up yytext */
	*yy_cp = (yy_hold_char);

	if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
		{ /* need to shift things up to make room */
		/* +2 for EOB chars. */
		register yy_size_t number_to_move = (yy_n_chars) + 2;
		register char *dest = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[
					YY_CURRENT_BUFFER_LVALUE->yy_buf_size + 2];
		register char *source =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move];

		while ( source > YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			*--dest = *--source;

		yy_cp += (int) (dest - source);
		yy_bp += (int) (dest - source);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars =
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_buf_size;

		if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
			YY_FATAL_ERROR( "flex scanner push-back overflow" );
		}

	*--yy_cp = (char) c;

	(yytext_ptr) = yy_bp;
	(yy_hold_char) = *yy_cp;
	(yy_c_buf_p) = yy_cp;
}

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			yy_size_t offset = (yy_c_buf_p) - (yytext_ptr);
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart(yyin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap( ) )
						return 0;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve yytext */
	(yy_hold_char) = *++(yy_c_buf_p);

	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = (c == '\n');

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer(yyin,YY_BUF_SIZE );
	}

	yy_init_buffer(YY_CURRENT_BUFFER,input_file );
	yy_load_buffer_state( );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state( );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void yy_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc(b->yy_buf_size + 2  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer(b,file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * 
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree((void *) b->yy_ch_buf  );

	yyfree((void *) b  );
}

#ifndef __cplusplus
extern int isatty (int );
#endif /* __cplusplus */
    
/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	yy_flush_buffer(b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state( );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack();

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state( );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void yypop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state( );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (void)
{
	yy_size_t num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );
								  
		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) yyalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = 0;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer(b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (yyconst char * yystr )
{
    
	return yy_scan_bytes(yystr,strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param bytes the byte buffer to scan
 * @param len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (yyconst char * yybytes, yy_size_t  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n, i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = _yybytes_len + 2;
	buf = (char *) yyalloc(n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer(buf,n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

    static void yy_push_state (int  new_state )
{
    	if ( (yy_start_stack_ptr) >= (yy_start_stack_depth) )
		{
		yy_size_t new_size;

		(yy_start_stack_depth) += YY_START_STACK_INCR;
		new_size = (yy_start_stack_depth) * sizeof( int );

		if ( ! (yy_start_stack) )
			(yy_start_stack) = (int *) yyalloc(new_size  );

		else
			(yy_start_stack) = (int *) yyrealloc((void *) (yy_start_stack),new_size  );

		if ( ! (yy_start_stack) )
			YY_FATAL_ERROR( "out of memory expanding start-condition stack" );
		}

	(yy_start_stack)[(yy_start_stack_ptr)++] = YY_START;

	BEGIN(new_state);
}

    static void yy_pop_state  (void)
{
    	if ( --(yy_start_stack_ptr) < 0 )
		YY_FATAL_ERROR( "start-condition stack underflow" );

	BEGIN((yy_start_stack)[(yy_start_stack_ptr)]);
}

    static int yy_top_state  (void)
{
    	return (yy_start_stack)[(yy_start_stack_ptr) - 1];
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yy_fatal_error (yyconst char* msg )
{
    	(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = (yy_hold_char); \
		(yy_c_buf_p) = yytext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int yyget_lineno  (void)
{
        
    return yylineno;
}

/** Get the input stream.
 * 
 */
FILE *yyget_in  (void)
{
        return yyin;
}

/** Get the output stream.
 * 
 */
FILE *yyget_out  (void)
{
        return yyout;
}

/** Get the length of the current token.
 * 
 */
yy_size_t yyget_leng  (void)
{
        return yyleng;
}

/** Get the current token.
 * 
 */

char *yyget_text  (void)
{
        return yytext;
}

/** Set the current line number.
 * @param line_number
 * 
 */
void yyset_lineno (int  line_number )
{
    
    yylineno = line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param in_str A readable stream.
 * 
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  in_str )
{
        yyin = in_str ;
}

void yyset_out (FILE *  out_str )
{
        yyout = out_str ;
}

int yyget_debug  (void)
{
        return yy_flex_debug;
}

void yyset_debug (int  bdebug )
{
        yy_flex_debug = bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = 0;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = (char *) 0;
    (yy_init) = 0;
    (yy_start) = 0;

    (yy_start_stack_ptr) = 0;
    (yy_start_stack_depth) = 0;
    (yy_start_stack) =  NULL;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = (FILE *) 0;
    yyout = (FILE *) 0;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer(YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state();
	}

	/* Destroy the stack itself. */
	yyfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Destroy the start condition stack. */
        yyfree((yy_start_stack)  );
        (yy_start_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n )
{
	register int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s )
{
	register int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size )
{
	return (void *) malloc( size );
}

void *yyrealloc  (void * ptr, yy_size_t  size )
{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void yyfree (void * ptr )
{
	free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 628 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp559z0ljd/sip/code_generator/metasrc/lexer.l"



/*
 * Hook into EOF handling.  Return 0 if there is more to process.
 */

int yywrap(void)
{
    char *cwd;
    struct inputFile *ifp;

    if ((cwd = inputFileStack[currentFile].cwd) != NULL)
        free(cwd);

    ifp = &inputFileStack[currentFile--];

    /* Tell the parser if this is the end of a file. */
    parserEOF(ifp->sloc.name, &ifp->pc);

    /*
     * Tidy up this file.  Note that we don't free the filename as it will
     * still be referenced for use in error messages.
     */
    fclose(yyin);

    /* See if this was the original file. */
    if (currentFile < 0)
        return 1;

    yy_delete_buffer(YY_CURRENT_BUFFER);
    yy_switch_to_buffer(ifp->bs);

    return 0;
}


/*
 * Initialise the lexer.
 */
void initialiseLexer(void)
{
    /* Initialise all the globals. */
    currentFile = -1;
    codeIdx = -1;
    parenDepth = 0;
    allFiles = NULL;
}


/*
 * Get the current source location.
 */
void getSourceLocation(sourceLocation *slp)
{
    int cf;

    /*
     * Assume that we will already have gone past the newline but watch out in
     * case we have gone past the end of the file.
     */
    if ((cf = currentFile) < 0)
    {
        /* This will be valid if we have been called. */
        cf = 0;
    }

    slp->linenr = inputFileStack[cf].sloc.linenr - 1;
    slp->name = inputFileStack[cf].sloc.name;
}


/*
 * Set up an input file to be read by the lexer, opening it if necessary.  TRUE
 * is returned if the file has not already been read.
 */
int setInputFile(FILE *open_fp, parserContext *pc, int optional)
{
    char *cwd, *fullname = NULL;
    FILE *fp = open_fp;

    if (currentFile >= MAX_INCLUDE_DEPTH - 1)
        fatal("Too many nested %%Include, %%OptionalInclude or %%Import statements\n");

    if (fp != NULL || (fp = openFile(pc->filename)) != NULL)
        fullname = sipStrdup(pc->filename);
    else
    {
        char *cwd;

        /* Try the directory that contains the current file. */
        if (currentFile >= 0 && (cwd = inputFileStack[currentFile].cwd) != NULL)
        {
            fullname = concat(cwd, "/", pc->filename, NULL);

            if ((fp = openFile(fullname)) == NULL)
            {
                free(fullname);
                fullname = NULL;
            }
        }
    }

    /* Try the include path if we haven't found anything yet. */
    if (fullname == NULL)
    {
        stringList *sl;

        fullname = NULL;

        for (sl = includeDirList; sl != NULL; sl = sl -> next)
        {
            if (fullname != NULL)
                free(fullname);

            fullname = concat(sl->s, "/", pc->filename, NULL);

            if ((fp = openFile(fullname)) != NULL)
                break;
        }

        if (fp == NULL)
        {
            if (optional)
                return FALSE;

            fatal("Unable to find file \"%s\"\n", pc->filename);
        }
    }

    /*
     * If we have just opened the file, make sure that we haven't already read
     * it.  While it should never happen with normal modules (if the user
     * doesn't specify recursive %Imports or %Includes) it is likely to happen
     * with consolidated modules.
     */
    if (open_fp == NULL)
    {
        stringList *sl;

        for (sl = allFiles; sl != NULL; sl = sl->next)
            if (strcmp(sl->s, fullname) == 0)
            {
                fclose(fp);
                return FALSE;
            }
    }

    /* Remember the filename. */
    appendString(&allFiles, sipStrdup(fullname));

    yyin = fp;

    ++currentFile;

    /* Remember the directory containing the new file and make it "current". */
    if ((cwd = strchr(fullname, '/')) != NULL)
    {
        cwd = sipStrdup(fullname);
        *strrchr(cwd,'/') = '\0';
    }

    inputFileStack[currentFile].sloc.linenr = 1;
    inputFileStack[currentFile].sloc.name = fullname;
    inputFileStack[currentFile].pc = *pc;
    inputFileStack[currentFile].cwd = cwd;

    if (currentFile > 0)
    {
        inputFileStack[currentFile].bs = YY_CURRENT_BUFFER;
        yy_switch_to_buffer(yy_create_buffer(yyin,YY_BUF_SIZE));
    }

    return TRUE;
}


/*
 * Open a file for reading or return NULL if it doesn't exist.  Any other error
 * is fatal.
 */
static FILE *openFile(const char *name)
{
    FILE *fp;

    if ((fp = fopen(name,"r")) == NULL && errno != ENOENT)
        fatal("Error in opening file %s\n",name);

    return fp;
}


/*
 * Handle fatal yacc errors.
 */
void yyerror(char *s)
{
    if (currentFile < 0)
        fatal("%s\n", s);

    fatal("%s:%d: %s\n", inputFileStack[currentFile].sloc.name,
            inputFileStack[currentFile].sloc.linenr, s);
}


/*
 * Handle warnings while parsing.
 */
void yywarning(char *s)
{
    warning(ParserWarning, "%s:%d: %s\n",
            inputFileStack[currentFile].sloc.name,
            inputFileStack[currentFile].sloc.linenr, s);
}


/*
 * Handle deprecation warnings.
 */
void deprecated(const char *msg)
{
    warning(DeprecationWarning, "%s:%d: %s\n",
            inputFileStack[currentFile].sloc.name,
            inputFileStack[currentFile].sloc.linenr, msg);
}


/*
 * Handle fatal lex errors.
 */
static void fatallex(char *s)
{
    fatal("%s:%d: Lexical analyser error: %s\n",
        inputFileStack[currentFile].sloc.name,
        inputFileStack[currentFile].sloc.linenr,
        s);
}


/*
 * Reset the lexer state to INITIAL.  This is used by directives that allow an
 * argument to be given without parentheses to get out of the 'directive_start'
 * state before an opening parenthesis is seen in another context.
 */
void resetLexerState(void)
{
    BEGIN INITIAL;
}

